(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    297135,       6006]
NotebookOptionsPosition[    296232,       5969]
NotebookOutlinePosition[    296589,       5985]
CellTagsIndexPosition[    296546,       5982]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Initialize", "Section",
 CellChangeTimes->{{3.50552484031266*^9, 3.505524843872361*^9}, {
  3.5055248781114607`*^9, 3.505524885704536*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Needs", "[", 
    RowBox[{"\"\<Bulatov`common`\>\"", ",", "\"\<Bulatov`showGraphs`\>\""}], 
    "]"}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"initGraph", "[", "graph_Graph", "]"}], ":=", 
    RowBox[{"(", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"g", "=", "graph"}], ";", "\[IndentingNewLine]", 
      RowBox[{"V", "=", 
       RowBox[{"VertexList", "[", "g", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"n", "=", 
       RowBox[{"Length", "@", "V"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"edges", "=", 
       RowBox[{"List", "@@@", 
        RowBox[{"EdgeList", "[", "g", "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"vcoords", "=", 
       RowBox[{"VertexCoordinates", "/.", 
        RowBox[{"AbsoluteOptions", "[", 
         RowBox[{"g", ",", "VertexCoordinates"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"edgesO", "=", 
       RowBox[{"edges", "~", "Join", "~", 
        RowBox[{"(", 
         RowBox[{"Reverse", "/@", "edges"}], ")"}]}]}], ";"}], 
     "\[IndentingNewLine]", ")"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"directed", " ", "count", " ", "constraint"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"counterCons", "[", 
     RowBox[{"{", 
      RowBox[{"i_", ",", "j_"}], "}"}], "]"}], ":=", 
    RowBox[{"(", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"e", "[", 
        RowBox[{"i", ",", "j"}], "]"}], "\[Implies]", 
       RowBox[{"(", 
        RowBox[{"Or", "@@", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"v", "[", 
             RowBox[{"i", ",", "k"}], "]"}], "&&", 
            RowBox[{"v", "[", 
             RowBox[{"j", ",", 
              RowBox[{"Mod", "[", 
               RowBox[{
                RowBox[{"k", "+", "1"}], ",", "n", " ", ",", "1"}], "]"}]}], 
             "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"k", ",", "1", ",", "n"}], "}"}]}], "]"}]}], ")"}]}], 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{"Equivalent", "[", 
      RowBox[{
       RowBox[{"e", "[", 
        RowBox[{"i", ",", "j"}], "]"}], ",", 
       RowBox[{"Or", "@@", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"v", "[", 
            RowBox[{"i", ",", "k"}], "]"}], "&&", 
           RowBox[{"v", "[", 
            RowBox[{"j", ",", 
             RowBox[{"Mod", "[", 
              RowBox[{
               RowBox[{"k", "+", "1"}], ",", "n", ",", "1"}], "]"}]}], 
            "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "1", ",", "n"}], "}"}]}], "]"}]}]}], "]"}], 
     "\[IndentingNewLine]", ")"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "every", " ", "vertex", " ", "must", " ", "have", " ", "one", " ", 
    "incoming", " ", "and", " ", "one", " ", "outgoing", " ", "edge"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"flowCons", "[", "vert_", "]"}], ":=", 
    RowBox[{"(", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"children", "=", 
       RowBox[{"Complement", "[", 
        RowBox[{
         RowBox[{"VertexList", "@", 
          RowBox[{"NeighborhoodGraph", "[", 
           RowBox[{"g", ",", "vert"}], "]"}]}], ",", 
         RowBox[{"{", "vert", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"outCh", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"e", "[", 
          RowBox[{"vert", ",", "#"}], "]"}], "&"}], "/@", "children"}]}], ";",
       "\[IndentingNewLine]", 
      RowBox[{"inCh", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"e", "[", 
          RowBox[{"#", ",", "vert"}], "]"}], "&"}], "/@", "children"}]}], ";",
       "\[IndentingNewLine]", 
      RowBox[{"outCount", "=", 
       RowBox[{"BooleanCountingFunction", "[", 
        RowBox[{
         RowBox[{"{", "1", "}"}], ",", "outCh"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"inCount", "=", 
       RowBox[{"BooleanCountingFunction", "[", 
        RowBox[{
         RowBox[{"{", "1", "}"}], ",", "inCh"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"inCount", "&&", "outCount"}]}], "\[IndentingNewLine]", ")"}]}],
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "every", " ", "edge", " ", "must", " ", "have", " ", "one", " ", 
    "direction"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"directionCons", "[", 
     RowBox[{"i_", "\[UndirectedEdge]", "j_"}], "]"}], ":=", 
    RowBox[{"(", "\[IndentingNewLine]", 
     RowBox[{"Not", "[", 
      RowBox[{
       RowBox[{"e", "[", 
        RowBox[{"i", ",", "j"}], "]"}], "&&", 
       RowBox[{"e", "[", 
        RowBox[{"j", ",", "i"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
     ")"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"every", " ", "vertex", " ", "gets", " ", "one", " ", "number"}], 
   " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"vertCons", "[", "i_", "]"}], ":=", 
    RowBox[{"(", "\[IndentingNewLine]", 
     RowBox[{"BooleanCountingFunction", "[", 
      RowBox[{
       RowBox[{"{", "1", "}"}], ",", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"v", "[", 
          RowBox[{"i", ",", "k"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"k", ",", "1", ",", "n"}], "}"}]}], "]"}]}], "]"}], 
     "\[IndentingNewLine]", ")"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"initCons", "[", "consTypes__", "]"}], ":=", 
    RowBox[{"(", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"edgeVars", "=", 
       RowBox[{"e", "@@@", "edgesO"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"vertVars", "=", 
       RowBox[{"Flatten", "@", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"v", "[", 
           RowBox[{"i", ",", "k"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "n"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"k", ",", "1", ",", "n"}], "}"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"vars", "=", 
       RowBox[{"edgeVars", "~", "Join", "~", "vertVars"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"flowC", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"flowCons", "[", "v", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"v", ",", 
           RowBox[{"VertexList", "[", "g", "]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"dirC", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"directionCons", "[", "edge", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"edge", ",", 
           RowBox[{"EdgeList", "[", "g", "]"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"eulerianC", "=", 
       RowBox[{"flowC", "~", "Join", "~", "dirC"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"counterC", "=", " ", 
       RowBox[{"counterCons", "/@", "edgesO"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"vertC", "=", 
       RowBox[{"vertCons", "/@", 
        RowBox[{"VertexList", "[", "g", "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"AppendTo", "[", 
       RowBox[{"vertC", ",", 
        RowBox[{"v", "[", 
         RowBox[{"1", ",", "1"}], "]"}]}], "]"}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
       "fix", " ", "vertex", " ", "1", " ", "to", " ", "have", " ", "index", 
        " ", "1"}], " ", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"clauses", "=", 
       RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"MemberQ", "[", 
         RowBox[{
          RowBox[{"{", "consTypes", "}"}], ",", "\"\<eulerian\>\""}], "]"}], 
        ",", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"clauses", ",", "eulerianC"}], "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"MemberQ", "[", 
         RowBox[{
          RowBox[{"{", "consTypes", "}"}], ",", "\"\<counter\>\""}], "]"}], 
        ",", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"clauses", ",", "counterC"}], "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"MemberQ", "[", 
         RowBox[{
          RowBox[{"{", "consTypes", "}"}], ",", "\"\<vertex\>\""}], "]"}], 
        ",", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"clauses", ",", "vertC"}], "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"clauses", "=", 
       RowBox[{"fl1", "@", "clauses"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"formula", "=", 
       RowBox[{"And", "@@", "clauses"}]}], ";"}], "\[IndentingNewLine]", 
     ")"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"drawArrows", "[", 
     RowBox[{"g_Graph", ",", "dirs_List"}], "]"}], ":=", 
    RowBox[{"(", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"red", "=", 
       RowBox[{
        RowBox[{"ColorData", "[", "\"\<Crayola\>\"", "]"}], "[", 
        "\"\<WildWatermelon\>\"", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{"red", ",", "Thick", ",", 
         RowBox[{"Opacity", "[", ".5", "]"}], ",", 
         RowBox[{"Arrowheads", "[", "Large", "]"}], ",", 
         RowBox[{"GraphicsComplex", "[", 
          RowBox[{"vcoords", ",", 
           RowBox[{"Arrow", "/@", "dirs"}]}], "]"}]}], "}"}], "]"}]}], 
     "\[IndentingNewLine]", ")"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "gives", " ", "list", " ", "of", " ", "edges", " ", "in", " ", "given", 
    " ", "Hamiltonian", " ", "path", " ", "instance"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"decodeInstance", "[", "vals_", "]"}], ":=", 
    RowBox[{"(", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"chosen", "=", 
       RowBox[{"Extract", "[", 
        RowBox[{"vars", ",", 
         RowBox[{"Position", "[", 
          RowBox[{"vals", ",", "True"}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"chosenEdges", "=", 
       RowBox[{"Rule", "@@@", 
        RowBox[{"Cases", "[", 
         RowBox[{"chosen", ",", "_e"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Rule", "@@@", "chosenEdges"}]}], "\[IndentingNewLine]", 
     ")"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"drawInstance", "[", "vals_", "]"}], ":=", 
   RowBox[{"(", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"chosen", "=", 
      RowBox[{"Extract", "[", 
       RowBox[{"vars", ",", 
        RowBox[{"Position", "[", 
         RowBox[{"vals", ",", "True"}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"chosenEdges", "=", 
      RowBox[{"Rule", "@@@", 
       RowBox[{"Cases", "[", 
        RowBox[{"chosen", ",", "_e"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"chosenNums", "=", 
      RowBox[{"List", "@@@", 
       RowBox[{"Cases", "[", 
        RowBox[{"chosen", ",", "_v"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"chosen", "=", 
      RowBox[{"Extract", "[", 
       RowBox[{"vars", ",", 
        RowBox[{"Position", "[", 
         RowBox[{"vals", ",", "True"}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"labels", "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", 
         RowBox[{"Style", "[", 
          RowBox[{
           RowBox[{"#", "[", 
            RowBox[{"[", "2", "]"}], "]"}], ",", "Bold", ",", "12"}], "]"}]}],
         "&"}], "/@", "chosenNums"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"gg", "=", 
      RowBox[{"Graph", "[", 
       RowBox[{"V", ",", 
        RowBox[{"UndirectedEdge", "@@@", "edges"}], ",", 
        RowBox[{"VertexCoordinates", "\[Rule]", "vcoords"}], ",", 
        RowBox[{"VertexLabels", "\[Rule]", "labels"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Show", "[", 
      RowBox[{"gg", ",", 
       RowBox[{"drawArrows", "[", 
        RowBox[{"g", ",", 
         RowBox[{"List", "@@@", "chosenEdges"}]}], "]"}]}], "]"}]}], 
    "\[IndentingNewLine]", ")"}]}], ";"}], "\[IndentingNewLine]"}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.505524861532227*^9, 3.505524880660727*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Hamiltonian Paths", "Section",
 CellChangeTimes->{{3.505525042024083*^9, 3.505525049287869*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"initGraph", "[", 
   RowBox[{"GraphData", "[", "\"\<BislitCube\>\"", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"initCons", "[", 
  RowBox[{"\"\<eulerian\>\"", ",", "\"\<counter\>\"", ",", "\"\<vertex\>\""}],
   "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sats", "=", 
   RowBox[{"SatisfiabilityInstances", "[", 
    RowBox[{"formula", ",", "vars", ",", "20"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"drawInstance", "/@", "sats"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{GraphicsGroupBox[{
        {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
         0.7]}], {DiskBox[{0., 1.}, 0.01842105263157895], InsetBox[
           StyleBox["1",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.02445990495970464, 1.0244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["2",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.024459904959704643`, 0.024459904959704567`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {
          DiskBox[{-0.5, 1.5}, 0.01842105263157895], InsetBox[
           StyleBox["4",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {-0.47554009504029515`, 1.5244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {
          DiskBox[{-0.5, 0.5}, 0.01842105263157895], InsetBox[
           StyleBox["3",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {-0.4755400950402952, 0.5244599049597047}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{1., 1.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["8",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {1.024459904959705, 1.0244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["7",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {1.024459904959705, 0.02445990495970451}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0.5, 1.5}, 0.01842105263157895],
           InsetBox[
           StyleBox["5",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.5244599049597046, 1.5244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0.5, 0.5}, 0.01842105263157895],
           InsetBox[
           StyleBox["6",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.5244599049597046, 0.5244599049597047}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}}, 
        {Hue[0.6, 0.7, 0.5], Opacity[0.7], LineBox[CompressedData["
1:eJxTTMoPSmVmYGDgA2ImKIaABXuuyUj5LXjyzh7GbzCKk/u9daG9yvfSfBae
mfvvXN8raJDywb5/AcdO+/x7+1U0nN6dn/3dfgJUHUTfB3tUcz7YS0L13/oG
puH6eyE0mn5Md9yE6oPp74Lq64HSEHUP9mfx8aoHFH2H87UeP90YL/3Q/rua
FUvYs7v77ZvXXzW8/N2+WliWSfvzO/uDNQFa53Q+2K+xNJnjcPLufoi+H/bL
IHx7GB8m/+8/CNyHy8P4uPwNCz+PgJY7883f28PCb/v6auWEEw/sYeEHk78H
9R9MHua/P1B7YP6D8WH+AwBfMci1
          "]]}}], {}}, 
     {RGBColor[0.9882352941176471, 0.4235294117647059, 0.5215686274509804], 
      Thickness[Large], Opacity[0.5], Arrowheads[Large], 
      GraphicsComplexBox[{{0., 1.}, {0., 0.}, {-0.5, 1.5}, {-0.5, 0.5}, {1., 
       1.}, {1., 0.}, {0.5, 1.5}, {0.5, 
       0.5}}, {ArrowBox[{1, 2}], ArrowBox[{2, 4}], ArrowBox[{3, 7}], 
        ArrowBox[{7, 8}], ArrowBox[{5, 1}], ArrowBox[{4, 3}], 
        ArrowBox[{6, 5}], ArrowBox[{8, 6}]}]}},
    FrameTicks->None,
    ImageSize->Tiny], ",", 
   GraphicsBox[{{GraphicsGroupBox[{
        {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
         0.7]}], {DiskBox[{0., 1.}, 0.01842105263157895], InsetBox[
           StyleBox["1",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.02445990495970464, 1.0244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["2",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.024459904959704643`, 0.024459904959704567`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {
          DiskBox[{-0.5, 1.5}, 0.01842105263157895], InsetBox[
           StyleBox["8",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {-0.47554009504029515`, 1.5244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {
          DiskBox[{-0.5, 0.5}, 0.01842105263157895], InsetBox[
           StyleBox["3",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {-0.4755400950402952, 0.5244599049597047}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{1., 1.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["6",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {1.024459904959705, 1.0244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["5",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {1.024459904959705, 0.02445990495970451}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0.5, 1.5}, 0.01842105263157895],
           InsetBox[
           StyleBox["7",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.5244599049597046, 1.5244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0.5, 0.5}, 0.01842105263157895],
           InsetBox[
           StyleBox["4",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.5244599049597046, 0.5244599049597047}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}}, 
        {Hue[0.6, 0.7, 0.5], Opacity[0.7], LineBox[CompressedData["
1:eJxTTMoPSmVmYGDgA2ImKIaABXuuyUj5LXjyzh7GbzCKk/u9daG9yvfSfBae
mfvvXN8raJDywb5/AcdO+/x7+1U0nN6dn/3dfgJUHUTfB3tUcz7YS0L13/oG
puH6eyE0mn5Md9yE6oPp74Lq64HSEHUP9mfx8aoHFH2H87UeP90YL/3Q/rua
FUvYs7v77ZvXXzW8/N2+WliWSfvzO/uDNQFa53Q+2K+xNJnjcPLufoi+H/bL
IHx7GB8m/+8/CNyHy8P4uPwNCz+PgJY7883f28PCb/v6auWEEw/sYeEHk78H
9R9MHua/P1B7YP6D8WH+AwBfMci1
          "]]}}], {}}, 
     {RGBColor[0.9882352941176471, 0.4235294117647059, 0.5215686274509804], 
      Thickness[Large], Opacity[0.5], Arrowheads[Large], 
      GraphicsComplexBox[{{0., 1.}, {0., 0.}, {-0.5, 1.5}, {-0.5, 0.5}, {1., 
       1.}, {1., 0.}, {0.5, 1.5}, {0.5, 
       0.5}}, {ArrowBox[{1, 2}], ArrowBox[{2, 4}], ArrowBox[{4, 8}], 
        ArrowBox[{5, 7}], ArrowBox[{3, 1}], ArrowBox[{7, 3}], 
        ArrowBox[{6, 5}], ArrowBox[{8, 6}]}]}},
    FrameTicks->None,
    ImageSize->Tiny], ",", 
   GraphicsBox[{{GraphicsGroupBox[{
        {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
         0.7]}], {DiskBox[{0., 1.}, 0.01842105263157895], InsetBox[
           StyleBox["1",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.02445990495970464, 1.0244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["2",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.024459904959704643`, 0.024459904959704567`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {
          DiskBox[{-0.5, 1.5}, 0.01842105263157895], InsetBox[
           StyleBox["6",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {-0.47554009504029515`, 1.5244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {
          DiskBox[{-0.5, 0.5}, 0.01842105263157895], InsetBox[
           StyleBox["5",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {-0.4755400950402952, 0.5244599049597047}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{1., 1.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["8",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {1.024459904959705, 1.0244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["3",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {1.024459904959705, 0.02445990495970451}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0.5, 1.5}, 0.01842105263157895],
           InsetBox[
           StyleBox["7",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.5244599049597046, 1.5244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0.5, 0.5}, 0.01842105263157895],
           InsetBox[
           StyleBox["4",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.5244599049597046, 0.5244599049597047}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}}, 
        {Hue[0.6, 0.7, 0.5], Opacity[0.7], LineBox[CompressedData["
1:eJxTTMoPSmVmYGDgA2ImKIaABXuuyUj5LXjyzh7GbzCKk/u9daG9yvfSfBae
mfvvXN8raJDywb5/AcdO+/x7+1U0nN6dn/3dfgJUHUTfB3tUcz7YS0L13/oG
puH6eyE0mn5Md9yE6oPp74Lq64HSEHUP9mfx8aoHFH2H87UeP90YL/3Q/rua
FUvYs7v77ZvXXzW8/N2+WliWSfvzO/uDNQFa53Q+2K+xNJnjcPLufoi+H/bL
IHx7GB8m/+8/CNyHy8P4uPwNCz+PgJY7883f28PCb/v6auWEEw/sYeEHk78H
9R9MHua/P1B7YP6D8WH+AwBfMci1
          "]]}}], {}}, 
     {RGBColor[0.9882352941176471, 0.4235294117647059, 0.5215686274509804], 
      Thickness[Large], Opacity[0.5], Arrowheads[Large], 
      GraphicsComplexBox[{{0., 1.}, {0., 0.}, {-0.5, 1.5}, {-0.5, 0.5}, {1., 
       1.}, {1., 0.}, {0.5, 1.5}, {0.5, 
       0.5}}, {ArrowBox[{1, 2}], ArrowBox[{2, 6}], ArrowBox[{3, 7}], 
        ArrowBox[{6, 8}], ArrowBox[{5, 1}], ArrowBox[{4, 3}], 
        ArrowBox[{8, 4}], ArrowBox[{7, 5}]}]}},
    FrameTicks->None,
    ImageSize->Tiny], ",", 
   GraphicsBox[{{GraphicsGroupBox[{
        {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
         0.7]}], {DiskBox[{0., 1.}, 0.01842105263157895], InsetBox[
           StyleBox["1",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.02445990495970464, 1.0244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["2",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.024459904959704643`, 0.024459904959704567`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {
          DiskBox[{-0.5, 1.5}, 0.01842105263157895], InsetBox[
           StyleBox["8",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {-0.47554009504029515`, 1.5244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {
          DiskBox[{-0.5, 0.5}, 0.01842105263157895], InsetBox[
           StyleBox["7",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {-0.4755400950402952, 0.5244599049597047}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{1., 1.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["4",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {1.024459904959705, 1.0244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["3",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {1.024459904959705, 0.02445990495970451}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0.5, 1.5}, 0.01842105263157895],
           InsetBox[
           StyleBox["5",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.5244599049597046, 1.5244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0.5, 0.5}, 0.01842105263157895],
           InsetBox[
           StyleBox["6",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.5244599049597046, 0.5244599049597047}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}}, 
        {Hue[0.6, 0.7, 0.5], Opacity[0.7], LineBox[CompressedData["
1:eJxTTMoPSmVmYGDgA2ImKIaABXuuyUj5LXjyzh7GbzCKk/u9daG9yvfSfBae
mfvvXN8raJDywb5/AcdO+/x7+1U0nN6dn/3dfgJUHUTfB3tUcz7YS0L13/oG
puH6eyE0mn5Md9yE6oPp74Lq64HSEHUP9mfx8aoHFH2H87UeP90YL/3Q/rua
FUvYs7v77ZvXXzW8/N2+WliWSfvzO/uDNQFa53Q+2K+xNJnjcPLufoi+H/bL
IHx7GB8m/+8/CNyHy8P4uPwNCz+PgJY7883f28PCb/v6auWEEw/sYeEHk78H
9R9MHua/P1B7YP6D8WH+AwBfMci1
          "]]}}], {}}, 
     {RGBColor[0.9882352941176471, 0.4235294117647059, 0.5215686274509804], 
      Thickness[Large], Opacity[0.5], Arrowheads[Large], 
      GraphicsComplexBox[{{0., 1.}, {0., 0.}, {-0.5, 1.5}, {-0.5, 0.5}, {1., 
       1.}, {1., 0.}, {0.5, 1.5}, {0.5, 
       0.5}}, {ArrowBox[{1, 2}], ArrowBox[{2, 6}], ArrowBox[{5, 7}], 
        ArrowBox[{7, 8}], ArrowBox[{3, 1}], ArrowBox[{4, 3}], 
        ArrowBox[{8, 4}], ArrowBox[{6, 5}]}]}},
    FrameTicks->None,
    ImageSize->Tiny], ",", 
   GraphicsBox[{{GraphicsGroupBox[{
        {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
         0.7]}], {DiskBox[{0., 1.}, 0.01842105263157895], InsetBox[
           StyleBox["1",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.02445990495970464, 1.0244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["4",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.024459904959704643`, 0.024459904959704567`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {
          DiskBox[{-0.5, 1.5}, 0.01842105263157895], InsetBox[
           StyleBox["2",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {-0.47554009504029515`, 1.5244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {
          DiskBox[{-0.5, 0.5}, 0.01842105263157895], InsetBox[
           StyleBox["3",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {-0.4755400950402952, 0.5244599049597047}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{1., 1.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["8",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {1.024459904959705, 1.0244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["5",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {1.024459904959705, 0.02445990495970451}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0.5, 1.5}, 0.01842105263157895],
           InsetBox[
           StyleBox["7",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.5244599049597046, 1.5244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0.5, 0.5}, 0.01842105263157895],
           InsetBox[
           StyleBox["6",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.5244599049597046, 0.5244599049597047}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}}, 
        {Hue[0.6, 0.7, 0.5], Opacity[0.7], LineBox[CompressedData["
1:eJxTTMoPSmVmYGDgA2ImKIaABXuuyUj5LXjyzh7GbzCKk/u9daG9yvfSfBae
mfvvXN8raJDywb5/AcdO+/x7+1U0nN6dn/3dfgJUHUTfB3tUcz7YS0L13/oG
puH6eyE0mn5Md9yE6oPp74Lq64HSEHUP9mfx8aoHFH2H87UeP90YL/3Q/rua
FUvYs7v77ZvXXzW8/N2+WliWSfvzO/uDNQFa53Q+2K+xNJnjcPLufoi+H/bL
IHx7GB8m/+8/CNyHy8P4uPwNCz+PgJY7883f28PCb/v6auWEEw/sYeEHk78H
9R9MHua/P1B7YP6D8WH+AwBfMci1
          "]]}}], {}}, 
     {RGBColor[0.9882352941176471, 0.4235294117647059, 0.5215686274509804], 
      Thickness[Large], Opacity[0.5], Arrowheads[Large], 
      GraphicsComplexBox[{{0., 1.}, {0., 0.}, {-0.5, 1.5}, {-0.5, 0.5}, {1., 
       1.}, {1., 0.}, {0.5, 1.5}, {0.5, 
       0.5}}, {ArrowBox[{1, 3}], ArrowBox[{2, 6}], ArrowBox[{3, 4}], 
        ArrowBox[{6, 8}], ArrowBox[{5, 1}], ArrowBox[{4, 2}], 
        ArrowBox[{7, 5}], ArrowBox[{8, 7}]}]}},
    FrameTicks->None,
    ImageSize->Tiny], ",", 
   GraphicsBox[{{GraphicsGroupBox[{
        {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
         0.7]}], {DiskBox[{0., 1.}, 0.01842105263157895], InsetBox[
           StyleBox["1",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.02445990495970464, 1.0244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["6",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.024459904959704643`, 0.024459904959704567`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {
          DiskBox[{-0.5, 1.5}, 0.01842105263157895], InsetBox[
           StyleBox["2",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {-0.47554009504029515`, 1.5244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {
          DiskBox[{-0.5, 0.5}, 0.01842105263157895], InsetBox[
           StyleBox["5",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {-0.4755400950402952, 0.5244599049597047}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{1., 1.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["8",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {1.024459904959705, 1.0244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["7",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {1.024459904959705, 0.02445990495970451}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0.5, 1.5}, 0.01842105263157895],
           InsetBox[
           StyleBox["3",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.5244599049597046, 1.5244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0.5, 0.5}, 0.01842105263157895],
           InsetBox[
           StyleBox["4",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.5244599049597046, 0.5244599049597047}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}}, 
        {Hue[0.6, 0.7, 0.5], Opacity[0.7], LineBox[CompressedData["
1:eJxTTMoPSmVmYGDgA2ImKIaABXuuyUj5LXjyzh7GbzCKk/u9daG9yvfSfBae
mfvvXN8raJDywb5/AcdO+/x7+1U0nN6dn/3dfgJUHUTfB3tUcz7YS0L13/oG
puH6eyE0mn5Md9yE6oPp74Lq64HSEHUP9mfx8aoHFH2H87UeP90YL/3Q/rua
FUvYs7v77ZvXXzW8/N2+WliWSfvzO/uDNQFa53Q+2K+xNJnjcPLufoi+H/bL
IHx7GB8m/+8/CNyHy8P4uPwNCz+PgJY7883f28PCb/v6auWEEw/sYeEHk78H
9R9MHua/P1B7YP6D8WH+AwBfMci1
          "]]}}], {}}, 
     {RGBColor[0.9882352941176471, 0.4235294117647059, 0.5215686274509804], 
      Thickness[Large], Opacity[0.5], Arrowheads[Large], 
      GraphicsComplexBox[{{0., 1.}, {0., 0.}, {-0.5, 1.5}, {-0.5, 0.5}, {1., 
       1.}, {1., 0.}, {0.5, 1.5}, {0.5, 
       0.5}}, {ArrowBox[{1, 3}], ArrowBox[{2, 6}], ArrowBox[{3, 7}], 
        ArrowBox[{7, 8}], ArrowBox[{5, 1}], ArrowBox[{4, 2}], 
        ArrowBox[{8, 4}], ArrowBox[{6, 5}]}]}},
    FrameTicks->None,
    ImageSize->Tiny], ",", 
   GraphicsBox[{{GraphicsGroupBox[{
        {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
         0.7]}], {DiskBox[{0., 1.}, 0.01842105263157895], InsetBox[
           StyleBox["1",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.02445990495970464, 1.0244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["8",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.024459904959704643`, 0.024459904959704567`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {
          DiskBox[{-0.5, 1.5}, 0.01842105263157895], InsetBox[
           StyleBox["2",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {-0.47554009504029515`, 1.5244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {
          DiskBox[{-0.5, 0.5}, 0.01842105263157895], InsetBox[
           StyleBox["3",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {-0.4755400950402952, 0.5244599049597047}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{1., 1.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["6",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {1.024459904959705, 1.0244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["7",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {1.024459904959705, 0.02445990495970451}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0.5, 1.5}, 0.01842105263157895],
           InsetBox[
           StyleBox["5",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.5244599049597046, 1.5244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0.5, 0.5}, 0.01842105263157895],
           InsetBox[
           StyleBox["4",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.5244599049597046, 0.5244599049597047}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}}, 
        {Hue[0.6, 0.7, 0.5], Opacity[0.7], LineBox[CompressedData["
1:eJxTTMoPSmVmYGDgA2ImKIaABXuuyUj5LXjyzh7GbzCKk/u9daG9yvfSfBae
mfvvXN8raJDywb5/AcdO+/x7+1U0nN6dn/3dfgJUHUTfB3tUcz7YS0L13/oG
puH6eyE0mn5Md9yE6oPp74Lq64HSEHUP9mfx8aoHFH2H87UeP90YL/3Q/rua
FUvYs7v77ZvXXzW8/N2+WliWSfvzO/uDNQFa53Q+2K+xNJnjcPLufoi+H/bL
IHx7GB8m/+8/CNyHy8P4uPwNCz+PgJY7883f28PCb/v6auWEEw/sYeEHk78H
9R9MHua/P1B7YP6D8WH+AwBfMci1
          "]]}}], {}}, 
     {RGBColor[0.9882352941176471, 0.4235294117647059, 0.5215686274509804], 
      Thickness[Large], Opacity[0.5], Arrowheads[Large], 
      GraphicsComplexBox[{{0., 1.}, {0., 0.}, {-0.5, 1.5}, {-0.5, 0.5}, {1., 
       1.}, {1., 0.}, {0.5, 1.5}, {0.5, 
       0.5}}, {ArrowBox[{1, 3}], ArrowBox[{3, 4}], ArrowBox[{4, 8}], 
        ArrowBox[{5, 6}], ArrowBox[{2, 1}], ArrowBox[{6, 2}], 
        ArrowBox[{7, 5}], ArrowBox[{8, 7}]}]}},
    FrameTicks->None,
    ImageSize->Tiny], ",", 
   GraphicsBox[{{GraphicsGroupBox[{
        {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
         0.7]}], {DiskBox[{0., 1.}, 0.01842105263157895], InsetBox[
           StyleBox["1",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.02445990495970464, 1.0244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["8",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.024459904959704643`, 0.024459904959704567`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {
          DiskBox[{-0.5, 1.5}, 0.01842105263157895], InsetBox[
           StyleBox["2",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {-0.47554009504029515`, 1.5244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {
          DiskBox[{-0.5, 0.5}, 0.01842105263157895], InsetBox[
           StyleBox["7",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {-0.4755400950402952, 0.5244599049597047}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{1., 1.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["4",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {1.024459904959705, 1.0244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["5",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {1.024459904959705, 0.02445990495970451}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0.5, 1.5}, 0.01842105263157895],
           InsetBox[
           StyleBox["3",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.5244599049597046, 1.5244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0.5, 0.5}, 0.01842105263157895],
           InsetBox[
           StyleBox["6",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.5244599049597046, 0.5244599049597047}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}}, 
        {Hue[0.6, 0.7, 0.5], Opacity[0.7], LineBox[CompressedData["
1:eJxTTMoPSmVmYGDgA2ImKIaABXuuyUj5LXjyzh7GbzCKk/u9daG9yvfSfBae
mfvvXN8raJDywb5/AcdO+/x7+1U0nN6dn/3dfgJUHUTfB3tUcz7YS0L13/oG
puH6eyE0mn5Md9yE6oPp74Lq64HSEHUP9mfx8aoHFH2H87UeP90YL/3Q/rua
FUvYs7v77ZvXXzW8/N2+WliWSfvzO/uDNQFa53Q+2K+xNJnjcPLufoi+H/bL
IHx7GB8m/+8/CNyHy8P4uPwNCz+PgJY7883f28PCb/v6auWEEw/sYeEHk78H
9R9MHua/P1B7YP6D8WH+AwBfMci1
          "]]}}], {}}, 
     {RGBColor[0.9882352941176471, 0.4235294117647059, 0.5215686274509804], 
      Thickness[Large], Opacity[0.5], Arrowheads[Large], 
      GraphicsComplexBox[{{0., 1.}, {0., 0.}, {-0.5, 1.5}, {-0.5, 0.5}, {1., 
       1.}, {1., 0.}, {0.5, 1.5}, {0.5, 
       0.5}}, {ArrowBox[{1, 3}], ArrowBox[{3, 7}], ArrowBox[{5, 6}], 
        ArrowBox[{6, 8}], ArrowBox[{2, 1}], ArrowBox[{4, 2}], 
        ArrowBox[{8, 4}], ArrowBox[{7, 5}]}]}},
    FrameTicks->None,
    ImageSize->Tiny], ",", 
   GraphicsBox[{{GraphicsGroupBox[{
        {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
         0.7]}], {DiskBox[{0., 1.}, 0.01842105263157895], InsetBox[
           StyleBox["1",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.02445990495970464, 1.0244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["4",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.024459904959704643`, 0.024459904959704567`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {
          DiskBox[{-0.5, 1.5}, 0.01842105263157895], InsetBox[
           StyleBox["8",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {-0.47554009504029515`, 1.5244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {
          DiskBox[{-0.5, 0.5}, 0.01842105263157895], InsetBox[
           StyleBox["5",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {-0.4755400950402952, 0.5244599049597047}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{1., 1.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["2",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {1.024459904959705, 1.0244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["3",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {1.024459904959705, 0.02445990495970451}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0.5, 1.5}, 0.01842105263157895],
           InsetBox[
           StyleBox["7",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.5244599049597046, 1.5244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0.5, 0.5}, 0.01842105263157895],
           InsetBox[
           StyleBox["6",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.5244599049597046, 0.5244599049597047}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}}, 
        {Hue[0.6, 0.7, 0.5], Opacity[0.7], LineBox[CompressedData["
1:eJxTTMoPSmVmYGDgA2ImKIaABXuuyUj5LXjyzh7GbzCKk/u9daG9yvfSfBae
mfvvXN8raJDywb5/AcdO+/x7+1U0nN6dn/3dfgJUHUTfB3tUcz7YS0L13/oG
puH6eyE0mn5Md9yE6oPp74Lq64HSEHUP9mfx8aoHFH2H87UeP90YL/3Q/rua
FUvYs7v77ZvXXzW8/N2+WliWSfvzO/uDNQFa53Q+2K+xNJnjcPLufoi+H/bL
IHx7GB8m/+8/CNyHy8P4uPwNCz+PgJY7883f28PCb/v6auWEEw/sYeEHk78H
9R9MHua/P1B7YP6D8WH+AwBfMci1
          "]]}}], {}}, 
     {RGBColor[0.9882352941176471, 0.4235294117647059, 0.5215686274509804], 
      Thickness[Large], Opacity[0.5], Arrowheads[Large], 
      GraphicsComplexBox[{{0., 1.}, {0., 0.}, {-0.5, 1.5}, {-0.5, 0.5}, {1., 
       1.}, {1., 0.}, {0.5, 1.5}, {0.5, 
       0.5}}, {ArrowBox[{1, 5}], ArrowBox[{2, 4}], ArrowBox[{4, 8}], 
        ArrowBox[{5, 6}], ArrowBox[{3, 1}], ArrowBox[{6, 2}], 
        ArrowBox[{7, 3}], ArrowBox[{8, 7}]}]}},
    FrameTicks->None,
    ImageSize->Tiny], ",", 
   GraphicsBox[{{GraphicsGroupBox[{
        {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
         0.7]}], {DiskBox[{0., 1.}, 0.01842105263157895], InsetBox[
           StyleBox["1",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.02445990495970464, 1.0244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["6",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.024459904959704643`, 0.024459904959704567`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {
          DiskBox[{-0.5, 1.5}, 0.01842105263157895], InsetBox[
           StyleBox["8",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {-0.47554009504029515`, 1.5244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {
          DiskBox[{-0.5, 0.5}, 0.01842105263157895], InsetBox[
           StyleBox["7",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {-0.4755400950402952, 0.5244599049597047}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{1., 1.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["2",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {1.024459904959705, 1.0244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["5",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {1.024459904959705, 0.02445990495970451}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0.5, 1.5}, 0.01842105263157895],
           InsetBox[
           StyleBox["3",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.5244599049597046, 1.5244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0.5, 0.5}, 0.01842105263157895],
           InsetBox[
           StyleBox["4",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.5244599049597046, 0.5244599049597047}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}}, 
        {Hue[0.6, 0.7, 0.5], Opacity[0.7], LineBox[CompressedData["
1:eJxTTMoPSmVmYGDgA2ImKIaABXuuyUj5LXjyzh7GbzCKk/u9daG9yvfSfBae
mfvvXN8raJDywb5/AcdO+/x7+1U0nN6dn/3dfgJUHUTfB3tUcz7YS0L13/oG
puH6eyE0mn5Md9yE6oPp74Lq64HSEHUP9mfx8aoHFH2H87UeP90YL/3Q/rua
FUvYs7v77ZvXXzW8/N2+WliWSfvzO/uDNQFa53Q+2K+xNJnjcPLufoi+H/bL
IHx7GB8m/+8/CNyHy8P4uPwNCz+PgJY7883f28PCb/v6auWEEw/sYeEHk78H
9R9MHua/P1B7YP6D8WH+AwBfMci1
          "]]}}], {}}, 
     {RGBColor[0.9882352941176471, 0.4235294117647059, 0.5215686274509804], 
      Thickness[Large], Opacity[0.5], Arrowheads[Large], 
      GraphicsComplexBox[{{0., 1.}, {0., 0.}, {-0.5, 1.5}, {-0.5, 0.5}, {1., 
       1.}, {1., 0.}, {0.5, 1.5}, {0.5, 
       0.5}}, {ArrowBox[{1, 5}], ArrowBox[{2, 4}], ArrowBox[{5, 7}], 
        ArrowBox[{7, 8}], ArrowBox[{3, 1}], ArrowBox[{6, 2}], 
        ArrowBox[{4, 3}], ArrowBox[{8, 6}]}]}},
    FrameTicks->None,
    ImageSize->Tiny], ",", 
   GraphicsBox[{{GraphicsGroupBox[{
        {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
         0.7]}], {DiskBox[{0., 1.}, 0.01842105263157895], InsetBox[
           StyleBox["1",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.02445990495970464, 1.0244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["8",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.024459904959704643`, 0.024459904959704567`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {
          DiskBox[{-0.5, 1.5}, 0.01842105263157895], InsetBox[
           StyleBox["4",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {-0.47554009504029515`, 1.5244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {
          DiskBox[{-0.5, 0.5}, 0.01842105263157895], InsetBox[
           StyleBox["5",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {-0.4755400950402952, 0.5244599049597047}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{1., 1.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["2",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {1.024459904959705, 1.0244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["7",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {1.024459904959705, 0.02445990495970451}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0.5, 1.5}, 0.01842105263157895],
           InsetBox[
           StyleBox["3",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.5244599049597046, 1.5244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0.5, 0.5}, 0.01842105263157895],
           InsetBox[
           StyleBox["6",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.5244599049597046, 0.5244599049597047}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}}, 
        {Hue[0.6, 0.7, 0.5], Opacity[0.7], LineBox[CompressedData["
1:eJxTTMoPSmVmYGDgA2ImKIaABXuuyUj5LXjyzh7GbzCKk/u9daG9yvfSfBae
mfvvXN8raJDywb5/AcdO+/x7+1U0nN6dn/3dfgJUHUTfB3tUcz7YS0L13/oG
puH6eyE0mn5Md9yE6oPp74Lq64HSEHUP9mfx8aoHFH2H87UeP90YL/3Q/rua
FUvYs7v77ZvXXzW8/N2+WliWSfvzO/uDNQFa53Q+2K+xNJnjcPLufoi+H/bL
IHx7GB8m/+8/CNyHy8P4uPwNCz+PgJY7883f28PCb/v6auWEEw/sYeEHk78H
9R9MHua/P1B7YP6D8WH+AwBfMci1
          "]]}}], {}}, 
     {RGBColor[0.9882352941176471, 0.4235294117647059, 0.5215686274509804], 
      Thickness[Large], Opacity[0.5], Arrowheads[Large], 
      GraphicsComplexBox[{{0., 1.}, {0., 0.}, {-0.5, 1.5}, {-0.5, 0.5}, {1., 
       1.}, {1., 0.}, {0.5, 1.5}, {0.5, 
       0.5}}, {ArrowBox[{1, 5}], ArrowBox[{3, 4}], ArrowBox[{4, 8}], 
        ArrowBox[{5, 7}], ArrowBox[{2, 1}], ArrowBox[{6, 2}], 
        ArrowBox[{7, 3}], ArrowBox[{8, 6}]}]}},
    FrameTicks->None,
    ImageSize->Tiny], ",", 
   GraphicsBox[{{GraphicsGroupBox[{
        {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
         0.7]}], {DiskBox[{0., 1.}, 0.01842105263157895], InsetBox[
           StyleBox["1",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.02445990495970464, 1.0244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["8",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.024459904959704643`, 0.024459904959704567`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {
          DiskBox[{-0.5, 1.5}, 0.01842105263157895], InsetBox[
           StyleBox["6",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {-0.47554009504029515`, 1.5244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {
          DiskBox[{-0.5, 0.5}, 0.01842105263157895], InsetBox[
           StyleBox["7",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {-0.4755400950402952, 0.5244599049597047}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{1., 1.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["2",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {1.024459904959705, 1.0244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.01842105263157895], 
          InsetBox[
           StyleBox["3",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {1.024459904959705, 0.02445990495970451}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0.5, 1.5}, 0.01842105263157895],
           InsetBox[
           StyleBox["5",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.5244599049597046, 1.5244599049597047`}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0.5, 0.5}, 0.01842105263157895],
           InsetBox[
           StyleBox["4",
            StripOnInput->False,
            FontSize->12,
            FontWeight->Bold], 
           Offset[{2., 2.}, {0.5244599049597046, 0.5244599049597047}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}}, 
        {Hue[0.6, 0.7, 0.5], Opacity[0.7], LineBox[CompressedData["
1:eJxTTMoPSmVmYGDgA2ImKIaABXuuyUj5LXjyzh7GbzCKk/u9daG9yvfSfBae
mfvvXN8raJDywb5/AcdO+/x7+1U0nN6dn/3dfgJUHUTfB3tUcz7YS0L13/oG
puH6eyE0mn5Md9yE6oPp74Lq64HSEHUP9mfx8aoHFH2H87UeP90YL/3Q/rua
FUvYs7v77ZvXXzW8/N2+WliWSfvzO/uDNQFa53Q+2K+xNJnjcPLufoi+H/bL
IHx7GB8m/+8/CNyHy8P4uPwNCz+PgJY7883f28PCb/v6auWEEw/sYeEHk78H
9R9MHua/P1B7YP6D8WH+AwBfMci1
          "]]}}], {}}, 
     {RGBColor[0.9882352941176471, 0.4235294117647059, 0.5215686274509804], 
      Thickness[Large], Opacity[0.5], Arrowheads[Large], 
      GraphicsComplexBox[{{0., 1.}, {0., 0.}, {-0.5, 1.5}, {-0.5, 0.5}, {1., 
       1.}, {1., 0.}, {0.5, 1.5}, {0.5, 
       0.5}}, {ArrowBox[{1, 5}], ArrowBox[{3, 4}], ArrowBox[{5, 6}], 
        ArrowBox[{6, 8}], ArrowBox[{2, 1}], ArrowBox[{4, 2}], 
        ArrowBox[{7, 3}], ArrowBox[{8, 7}]}]}},
    FrameTicks->None,
    ImageSize->Tiny]}], "}"}]], "Output",
 CellChangeTimes->{3.50552507017273*^9, 3.5055251487449503`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"decodeInstance", "/@", "sats"}]], "Input",
 CellChangeTimes->{{3.505525156790613*^9, 3.505525159538393*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[Rule]", "2"}], ",", 
     RowBox[{"2", "\[Rule]", "4"}], ",", 
     RowBox[{"3", "\[Rule]", "7"}], ",", 
     RowBox[{"7", "\[Rule]", "8"}], ",", 
     RowBox[{"5", "\[Rule]", "1"}], ",", 
     RowBox[{"4", "\[Rule]", "3"}], ",", 
     RowBox[{"6", "\[Rule]", "5"}], ",", 
     RowBox[{"8", "\[Rule]", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[Rule]", "2"}], ",", 
     RowBox[{"2", "\[Rule]", "4"}], ",", 
     RowBox[{"4", "\[Rule]", "8"}], ",", 
     RowBox[{"5", "\[Rule]", "7"}], ",", 
     RowBox[{"3", "\[Rule]", "1"}], ",", 
     RowBox[{"7", "\[Rule]", "3"}], ",", 
     RowBox[{"6", "\[Rule]", "5"}], ",", 
     RowBox[{"8", "\[Rule]", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[Rule]", "2"}], ",", 
     RowBox[{"2", "\[Rule]", "6"}], ",", 
     RowBox[{"3", "\[Rule]", "7"}], ",", 
     RowBox[{"6", "\[Rule]", "8"}], ",", 
     RowBox[{"5", "\[Rule]", "1"}], ",", 
     RowBox[{"4", "\[Rule]", "3"}], ",", 
     RowBox[{"8", "\[Rule]", "4"}], ",", 
     RowBox[{"7", "\[Rule]", "5"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[Rule]", "2"}], ",", 
     RowBox[{"2", "\[Rule]", "6"}], ",", 
     RowBox[{"5", "\[Rule]", "7"}], ",", 
     RowBox[{"7", "\[Rule]", "8"}], ",", 
     RowBox[{"3", "\[Rule]", "1"}], ",", 
     RowBox[{"4", "\[Rule]", "3"}], ",", 
     RowBox[{"8", "\[Rule]", "4"}], ",", 
     RowBox[{"6", "\[Rule]", "5"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[Rule]", "3"}], ",", 
     RowBox[{"2", "\[Rule]", "6"}], ",", 
     RowBox[{"3", "\[Rule]", "4"}], ",", 
     RowBox[{"6", "\[Rule]", "8"}], ",", 
     RowBox[{"5", "\[Rule]", "1"}], ",", 
     RowBox[{"4", "\[Rule]", "2"}], ",", 
     RowBox[{"7", "\[Rule]", "5"}], ",", 
     RowBox[{"8", "\[Rule]", "7"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[Rule]", "3"}], ",", 
     RowBox[{"2", "\[Rule]", "6"}], ",", 
     RowBox[{"3", "\[Rule]", "7"}], ",", 
     RowBox[{"7", "\[Rule]", "8"}], ",", 
     RowBox[{"5", "\[Rule]", "1"}], ",", 
     RowBox[{"4", "\[Rule]", "2"}], ",", 
     RowBox[{"8", "\[Rule]", "4"}], ",", 
     RowBox[{"6", "\[Rule]", "5"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[Rule]", "3"}], ",", 
     RowBox[{"3", "\[Rule]", "4"}], ",", 
     RowBox[{"4", "\[Rule]", "8"}], ",", 
     RowBox[{"5", "\[Rule]", "6"}], ",", 
     RowBox[{"2", "\[Rule]", "1"}], ",", 
     RowBox[{"6", "\[Rule]", "2"}], ",", 
     RowBox[{"7", "\[Rule]", "5"}], ",", 
     RowBox[{"8", "\[Rule]", "7"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[Rule]", "3"}], ",", 
     RowBox[{"3", "\[Rule]", "7"}], ",", 
     RowBox[{"5", "\[Rule]", "6"}], ",", 
     RowBox[{"6", "\[Rule]", "8"}], ",", 
     RowBox[{"2", "\[Rule]", "1"}], ",", 
     RowBox[{"4", "\[Rule]", "2"}], ",", 
     RowBox[{"8", "\[Rule]", "4"}], ",", 
     RowBox[{"7", "\[Rule]", "5"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[Rule]", "5"}], ",", 
     RowBox[{"2", "\[Rule]", "4"}], ",", 
     RowBox[{"4", "\[Rule]", "8"}], ",", 
     RowBox[{"5", "\[Rule]", "6"}], ",", 
     RowBox[{"3", "\[Rule]", "1"}], ",", 
     RowBox[{"6", "\[Rule]", "2"}], ",", 
     RowBox[{"7", "\[Rule]", "3"}], ",", 
     RowBox[{"8", "\[Rule]", "7"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[Rule]", "5"}], ",", 
     RowBox[{"2", "\[Rule]", "4"}], ",", 
     RowBox[{"5", "\[Rule]", "7"}], ",", 
     RowBox[{"7", "\[Rule]", "8"}], ",", 
     RowBox[{"3", "\[Rule]", "1"}], ",", 
     RowBox[{"6", "\[Rule]", "2"}], ",", 
     RowBox[{"4", "\[Rule]", "3"}], ",", 
     RowBox[{"8", "\[Rule]", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[Rule]", "5"}], ",", 
     RowBox[{"3", "\[Rule]", "4"}], ",", 
     RowBox[{"4", "\[Rule]", "8"}], ",", 
     RowBox[{"5", "\[Rule]", "7"}], ",", 
     RowBox[{"2", "\[Rule]", "1"}], ",", 
     RowBox[{"6", "\[Rule]", "2"}], ",", 
     RowBox[{"7", "\[Rule]", "3"}], ",", 
     RowBox[{"8", "\[Rule]", "6"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[Rule]", "5"}], ",", 
     RowBox[{"3", "\[Rule]", "4"}], ",", 
     RowBox[{"5", "\[Rule]", "6"}], ",", 
     RowBox[{"6", "\[Rule]", "8"}], ",", 
     RowBox[{"2", "\[Rule]", "1"}], ",", 
     RowBox[{"4", "\[Rule]", "2"}], ",", 
     RowBox[{"7", "\[Rule]", "3"}], ",", 
     RowBox[{"8", "\[Rule]", "7"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5055251598303547`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show graphs", "Section",
 CellChangeTimes->{{3.505524900368581*^9, 3.505524907854258*^9}, {
  3.505524946684087*^9, 3.505524948235115*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"showGraphs", "[", 
  RowBox[{"12", ",", "\"\<Connected\>\"", ",", 
   RowBox[{"!", "\"\<Tree\>\""}], ",", "\"\<Planar\>\"", ",", 
   RowBox[{"gridSize", "\[Rule]", "6"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.505524976110756*^9, 3.505525000704813*^9}, {
   3.505525575043223*^9, 3.505525582823709*^9}, 3.50552561829053*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total: \"\>", "\[InvisibleSpace]", "66"}],
  SequenceForm["Total: ", 66],
  Editable->False]], "Print",
 CellChangeTimes->{{3.5055249548468647`*^9, 3.505525001863846*^9}, 
   3.505525117800632*^9, 3.5055256205233097`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 4, 8, 12, 16, 20, 24, 28, 32, 36, 40, 44, 48}, {{2}, {
                  3}, {4}, {5}, {1}, {4}, {6}, {8}, {1}, {5}, {6}, {9}, {1}, {
                  2}, {7}, {10}, {1}, {3}, {7}, {11}, {2}, {3}, {8}, {9}, {
                  4}, {5}, {10}, {11}, {2}, {6}, {10}, {12}, {3}, {6}, {11}, {
                  12}, {4}, {7}, {8}, {12}, {5}, {7}, {9}, {12}, {8}, {9}, {
                  10}, {11}}}, Pattern}]}, {
              VertexCoordinates -> {{-1., 
                0.}, {-0.3694, -0.3694}, {-0.7735, -0.7735}, {-0.3694, 
                0.3694}, {-0.7735, 0.7735}, {0., -1.}, {0., 1.}, {
                0.3694, -0.3694}, {0.7735, -0.7735}, {0.3694, 0.3694}, {
                0.7735, 0.7735}, {1., 0.}}}]], Typeset`boxes = 
            GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{-1., 0.}, 0.02261146496815286], "DynamicName", BoxID -> 
                "VertexID$1"], 
               TagBox[
                DiskBox[{-0.3694, -0.3694}, 0.02261146496815286], 
                "DynamicName", BoxID -> "VertexID$2"], 
               TagBox[
                DiskBox[{-0.7735, -0.7735}, 0.02261146496815286], 
                "DynamicName", BoxID -> "VertexID$3"], 
               TagBox[
                DiskBox[{-0.3694, 0.3694}, 0.02261146496815286], 
                "DynamicName", BoxID -> "VertexID$4"], 
               TagBox[
                DiskBox[{-0.7735, 0.7735}, 0.02261146496815286], 
                "DynamicName", BoxID -> "VertexID$5"], 
               TagBox[
                DiskBox[{0., -1.}, 0.02261146496815286], "DynamicName", BoxID -> 
                "VertexID$6"], 
               TagBox[
                DiskBox[{0., 1.}, 0.02261146496815286], "DynamicName", BoxID -> 
                "VertexID$7"], 
               TagBox[
                DiskBox[{0.3694, -0.3694}, 0.02261146496815286], 
                "DynamicName", BoxID -> "VertexID$8"], 
               TagBox[
                DiskBox[{0.7735, -0.7735}, 0.02261146496815286], 
                "DynamicName", BoxID -> "VertexID$9"], 
               TagBox[
                DiskBox[{0.3694, 0.3694}, 0.02261146496815286], "DynamicName",
                 BoxID -> "VertexID$10"], 
               TagBox[
                DiskBox[{0.7735, 0.7735}, 0.02261146496815286], "DynamicName",
                 BoxID -> "VertexID$11"], 
               TagBox[
                DiskBox[{1., 0.}, 0.02261146496815286], "DynamicName", BoxID -> 
                "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$2", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{0.22133333333333471`, 
              60.84533333333333}, {-61.77866666666668, -1.154666666666671}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         "\"CuboctahedralGraph\"",
         TooltipStyle->"TextStyling"],
        Annotation[#, "CuboctahedralGraph", "Tooltip"]& ],
       TraditionalForm], {195.42857142857142`, -195.42857142857142`}, {
      Center, Center}, {359.99999999999994`, 359.99999999999994`}], InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 33, 36}, {{2}, {
                  7}, {11}, {1}, {3}, {8}, {2}, {4}, {9}, {3}, {5}, {9}, {
                  4}, {6}, {10}, {5}, {7}, {10}, {1}, {6}, {11}, {2}, {11}, {
                  12}, {3}, {4}, {12}, {5}, {6}, {12}, {1}, {7}, {8}, {8}, {
                  9}, {10}}}, Pattern}]}, {
              VertexCoordinates -> {{0.782, 0.624}, {0., 1.}, {-0.782, 
                0.623}, {-0.975, -0.223}, {-0.434, -0.901}, {0.434, -0.901}, {
                0.975, -0.222}, {0.089, 0.39}, {-0.39, 
                0.089}, {-0.089, -0.39}, {0.39, -0.089}, {-0.086, 0.071}}}]], 
            Typeset`boxes = GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{0.782, 0.624}, 0.02220447284345045], "DynamicName", 
                BoxID -> "VertexID$1"], 
               TagBox[
                DiskBox[{0., 1.}, 0.02220447284345045], "DynamicName", BoxID -> 
                "VertexID$2"], 
               TagBox[
                DiskBox[{-0.782, 0.623}, 0.02220447284345045], "DynamicName", 
                BoxID -> "VertexID$3"], 
               TagBox[
                DiskBox[{-0.975, -0.223}, 0.02220447284345045], "DynamicName",
                 BoxID -> "VertexID$4"], 
               TagBox[
                DiskBox[{-0.434, -0.901}, 0.02220447284345045], "DynamicName",
                 BoxID -> "VertexID$5"], 
               TagBox[
                DiskBox[{0.434, -0.901}, 0.02220447284345045], "DynamicName", 
                BoxID -> "VertexID$6"], 
               TagBox[
                DiskBox[{0.975, -0.222}, 0.02220447284345045], "DynamicName", 
                BoxID -> "VertexID$7"], 
               TagBox[
                DiskBox[{0.089, 0.39}, 0.02220447284345045], "DynamicName", 
                BoxID -> "VertexID$8"], 
               TagBox[
                DiskBox[{-0.39, 0.089}, 0.02220447284345045], "DynamicName", 
                BoxID -> "VertexID$9"], 
               TagBox[
                DiskBox[{-0.089, -0.39}, 0.02220447284345045], "DynamicName", 
                BoxID -> "VertexID$10"], 
               TagBox[
                DiskBox[{0.39, -0.089}, 0.02220447284345045], "DynamicName", 
                BoxID -> "VertexID$11"], 
               TagBox[
                DiskBox[{-0.086, 0.071}, 0.02220447284345045], "DynamicName", 
                BoxID -> "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$2", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{-0.06770411476930738, 
              61.13437078143597}, {-61.34754689570644, \
-1.5857864376269006`}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         "\"FruchtGraph\"",
         TooltipStyle->"TextStyling"],
        Annotation[#, "FruchtGraph", "Tooltip"]& ],
       TraditionalForm], {586.2857142857142, -195.42857142857142`}, {
      Center, Center}, {359.99999999999994`, 359.99999999999994`}], InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 5, 10, 15, 20, 25, 30, 35, 40, 45, 50, 55, 60}, {{
                  3}, {5}, {6}, {9}, {10}, {4}, {7}, {8}, {11}, {12}, {1}, {
                  7}, {8}, {9}, {10}, {2}, {5}, {6}, {11}, {12}, {1}, {4}, {
                  6}, {9}, {11}, {1}, {4}, {5}, {10}, {12}, {2}, {3}, {8}, {
                  9}, {11}, {2}, {3}, {7}, {10}, {12}, {1}, {3}, {5}, {7}, {
                  11}, {1}, {3}, {6}, {8}, {12}, {2}, {4}, {5}, {7}, {9}, {
                  2}, {4}, {6}, {8}, {10}}}, Pattern}]}, {
              VertexCoordinates -> {{0., -0.314}, {0., 3.602}, {0., -1.165}, {
                0., 0.78}, {0.272, 0.157}, {-0.272, 0.157}, {
                3.12, -1.801}, {-3.12, -1.801}, {
                0.675, -0.39}, {-0.675, -0.39}, {1.009, 0.583}, {-1.009, 
                0.583}}}]], Typeset`boxes = GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{0., -0.314}, 0.049699097291875605`], "DynamicName", 
                BoxID -> "VertexID$1"], 
               TagBox[
                DiskBox[{0., 3.602}, 0.049699097291875605`], "DynamicName", 
                BoxID -> "VertexID$2"], 
               TagBox[
                DiskBox[{0., -1.165}, 0.049699097291875605`], "DynamicName", 
                BoxID -> "VertexID$3"], 
               TagBox[
                DiskBox[{0., 0.78}, 0.049699097291875605`], "DynamicName", 
                BoxID -> "VertexID$4"], 
               TagBox[
                DiskBox[{0.272, 0.157}, 0.049699097291875605`], "DynamicName",
                 BoxID -> "VertexID$5"], 
               TagBox[
                DiskBox[{-0.272, 0.157}, 0.049699097291875605`], 
                "DynamicName", BoxID -> "VertexID$6"], 
               TagBox[
                DiskBox[{3.12, -1.801}, 0.049699097291875605`], "DynamicName",
                 BoxID -> "VertexID$7"], 
               TagBox[
                DiskBox[{-3.12, -1.801}, 0.049699097291875605`], 
                "DynamicName", BoxID -> "VertexID$8"], 
               TagBox[
                DiskBox[{0.675, -0.39}, 0.049699097291875605`], "DynamicName",
                 BoxID -> "VertexID$9"], 
               TagBox[
                DiskBox[{-0.675, -0.39}, 0.049699097291875605`], 
                "DynamicName", BoxID -> "VertexID$10"], 
               TagBox[
                DiskBox[{1.009, 0.583}, 0.049699097291875605`], "DynamicName",
                 BoxID -> "VertexID$11"], 
               TagBox[
                DiskBox[{-1.009, 0.583}, 0.049699097291875605`], 
                "DynamicName", BoxID -> "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{-0.19288022903976443`, 
              61.25954689570646}, {-58.32277406959998, -4.585786437626903}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         "\"IcosahedralGraph\"",
         TooltipStyle->"TextStyling"],
        Annotation[#, "IcosahedralGraph", "Tooltip"]& ],
       TraditionalForm], {977.1428571428571, -195.42857142857142`}, {
      Center, Center}, {360., 359.99999999999994`}], InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 33, 36}, {{3}, {
                  9}, {11}, {4}, {10}, {12}, {1}, {5}, {9}, {2}, {6}, {10}, {
                  3}, {6}, {7}, {4}, {5}, {7}, {5}, {6}, {8}, {7}, {11}, {
                  12}, {1}, {3}, {10}, {2}, {4}, {9}, {1}, {8}, {12}, {2}, {
                  8}, {11}}}, Pattern}]}, {
              VertexCoordinates -> {{0.0008, 1.}, {-0.8664, -0.4993}, {0.6434,
                 0.7655}, {-0.3428, -0.9394}, {0.9849, 0.1729}, {
                0.3413, -0.94}, {0.8656, -0.5007}, {
                0.3463, -0.2003}, {-0.6422, 0.7666}, {-0.9847, 0.1744}, {
                0.0003, 0.4}, {-0.3466, -0.1997}}}]], Typeset`boxes = 
            GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{0.0008, 1.}, 0.022364323275642], "DynamicName", 
                BoxID -> "VertexID$1"], 
               TagBox[
                DiskBox[{-0.8664, -0.4993}, 0.022364323275642], "DynamicName",
                 BoxID -> "VertexID$2"], 
               TagBox[
                DiskBox[{0.6434, 0.7655}, 0.022364323275642], "DynamicName", 
                BoxID -> "VertexID$3"], 
               TagBox[
                DiskBox[{-0.3428, -0.9394}, 0.022364323275642], "DynamicName",
                 BoxID -> "VertexID$4"], 
               TagBox[
                DiskBox[{0.9849, 0.1729}, 0.022364323275642], "DynamicName", 
                BoxID -> "VertexID$5"], 
               TagBox[
                DiskBox[{0.3413, -0.94}, 0.022364323275642], "DynamicName", 
                BoxID -> "VertexID$6"], 
               TagBox[
                DiskBox[{0.8656, -0.5007}, 0.022364323275642], "DynamicName", 
                BoxID -> "VertexID$7"], 
               TagBox[
                DiskBox[{0.3463, -0.2003}, 0.022364323275642], "DynamicName", 
                BoxID -> "VertexID$8"], 
               TagBox[
                DiskBox[{-0.6422, 0.7666}, 0.022364323275642], "DynamicName", 
                BoxID -> "VertexID$9"], 
               TagBox[
                DiskBox[{-0.9847, 0.1744}, 0.022364323275642], "DynamicName", 
                BoxID -> "VertexID$10"], 
               TagBox[
                DiskBox[{0.0003, 0.4}, 0.022364323275642], "DynamicName", 
                BoxID -> "VertexID$11"], 
               TagBox[
                DiskBox[{-0.3466, -0.1997}, 0.022364323275642], "DynamicName",
                 BoxID -> "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{0.22133333333332672`, 
              60.84533333333339}, {-61.34793496780241, \
-1.5853983655308994`}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         "\"TruncatedTetrahedralGraph\"",
         TooltipStyle->"TextStyling"],
        Annotation[#, "TruncatedTetrahedralGraph", "Tooltip"]& ],
       TraditionalForm], {1368., -195.42857142857142`}, {
      Center, Center}, {360.0000000000002, 359.99999999999994`}], InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 4, 8, 12, 16, 20, 24, 28, 32, 36, 40, 44, 48}, {{2}, {
                  6}, {7}, {12}, {1}, {3}, {7}, {8}, {2}, {4}, {8}, {9}, {
                  3}, {5}, {9}, {10}, {4}, {6}, {10}, {11}, {1}, {5}, {11}, {
                  12}, {1}, {2}, {8}, {12}, {2}, {3}, {7}, {9}, {3}, {4}, {
                  8}, {10}, {4}, {5}, {9}, {11}, {5}, {6}, {10}, {12}, {1}, {
                  6}, {7}, {11}}}, Pattern}]}, {
              VertexCoordinates -> {{-1., 0.}, {-0.5, -0.866}, {
                0.5, -0.866}, {1., 0.}, {0.5, 0.866}, {-0.5, 
                0.866}, {-0.375, -0.217}, {0., -0.433}, {0.375, -0.217}, {
                0.375, 0.217}, {0., 0.433}, {-0.375, 0.217}}}]], 
            Typeset`boxes = GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{-1., 0.}, 0.02261146496815286], "DynamicName", BoxID -> 
                "VertexID$1"], 
               TagBox[
                DiskBox[{-0.5, -0.866}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$2"], 
               TagBox[
                DiskBox[{0.5, -0.866}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$3"], 
               TagBox[
                DiskBox[{1., 0.}, 0.02261146496815286], "DynamicName", BoxID -> 
                "VertexID$4"], 
               TagBox[
                DiskBox[{0.5, 0.866}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$5"], 
               TagBox[
                DiskBox[{-0.5, 0.866}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$6"], 
               TagBox[
                DiskBox[{-0.375, -0.217}, 0.02261146496815286], "DynamicName",
                 BoxID -> "VertexID$7"], 
               TagBox[
                DiskBox[{0., -0.433}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$8"], 
               TagBox[
                DiskBox[{0.375, -0.217}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$9"], 
               TagBox[
                DiskBox[{0.375, 0.217}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$10"], 
               TagBox[
                DiskBox[{0., 0.433}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$11"], 
               TagBox[
                DiskBox[{-0.375, 0.217}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$2", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{-0.18850520153014783`, 
              61.25517186819683}, {-58.34754689570642, -4.585786437626901}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Antiprism\"", ",", "6"}], "}"}]],
        Annotation[#, {"Antiprism", 6}, "Tooltip"]& ],
       TraditionalForm], {1758.8571428571427`, -195.42857142857142`}, {
      Center, Center}, {360.0000000000002, 359.99999999999994`}], InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 2, 4, 6, 8, 10, 16, 18, 20, 22, 24, 26, 32}, {{6}, {
                  7}, {6}, {8}, {6}, {9}, {6}, {10}, {6}, {11}, {1}, {2}, {
                  3}, {4}, {5}, {12}, {1}, {12}, {2}, {12}, {3}, {12}, {4}, {
                  12}, {5}, {12}, {6}, {7}, {8}, {9}, {10}, {11}}}, 
                 Pattern}]}, {
              VertexCoordinates -> {{4., 5.}, {2., 5.}, {5., 5.}, {6., 6.}, {
                1., 6.}, {3., 6.}, {4., 2.}, {2., 2.}, {5., 2.}, {6., 1.}, {
                1., 1.}, {3., 1.}}}]], Typeset`boxes = GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{4., 5.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$1"], 
               TagBox[
                DiskBox[{2., 5.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$2"], 
               TagBox[
                DiskBox[{5., 5.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$3"], 
               TagBox[
                DiskBox[{6., 6.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$4"], 
               TagBox[
                DiskBox[{1., 6.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$5"], 
               TagBox[
                DiskBox[{3., 6.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$6"], 
               TagBox[
                DiskBox[{4., 2.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$7"], 
               TagBox[
                DiskBox[{2., 2.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$8"], 
               TagBox[
                DiskBox[{5., 2.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$9"], 
               TagBox[
                DiskBox[{6., 1.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$10"], 
               TagBox[
                DiskBox[{1., 1.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$11"], 
               TagBox[
                DiskBox[{3., 1.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{-0.4142135623730949, 
              61.25954689570641}, {-62.192880229039744`, \
-0.5857864376269033}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Book\"", ",", "5"}], "}"}]],
        Annotation[#, {"Book", 5}, "Tooltip"]& ],
       TraditionalForm], {2149.7142857142853`, -195.42857142857142`}, {
      Center, Center}, {359.9999999999998, 359.99999999999994`}]}, {InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 3, 5, 8, 12, 15, 17, 20, 24, 27, 29, 32, 36}, {{3}, {
                  4}, {12}, {3}, {4}, {1}, {2}, {4}, {1}, {2}, {3}, {5}, {
                  4}, {7}, {8}, {7}, {8}, {5}, {6}, {8}, {5}, {6}, {7}, {9}, {
                  8}, {11}, {12}, {11}, {12}, {9}, {10}, {12}, {1}, {9}, {
                  10}, {11}}}, Pattern}]}, {
              VertexCoordinates -> {{1., -0.5}, {2., -0.5}, {2., 0.5}, {1., 
                0.5}, {-0.067, 1.116}, {-0.567, 1.9821}, {-1.433, 
                1.4821}, {-0.933, 
                0.616}, {-0.933, -0.616}, {-1.433, -1.4821}, {-0.567, \
-1.9821}, {-0.067, -1.116}}}]], Typeset`boxes = GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{1., -0.5}, 0.03677664428618335], "DynamicName", 
                BoxID -> "VertexID$1"], 
               TagBox[
                DiskBox[{2., -0.5}, 0.03677664428618335], "DynamicName", 
                BoxID -> "VertexID$2"], 
               TagBox[
                DiskBox[{2., 0.5}, 0.03677664428618335], "DynamicName", BoxID -> 
                "VertexID$3"], 
               TagBox[
                DiskBox[{1., 0.5}, 0.03677664428618335], "DynamicName", BoxID -> 
                "VertexID$4"], 
               TagBox[
                DiskBox[{-0.067, 1.116}, 0.03677664428618335], "DynamicName", 
                BoxID -> "VertexID$5"], 
               TagBox[
                DiskBox[{-0.567, 1.9821}, 0.03677664428618335], "DynamicName",
                 BoxID -> "VertexID$6"], 
               TagBox[
                DiskBox[{-1.433, 1.4821}, 0.03677664428618335], "DynamicName",
                 BoxID -> "VertexID$7"], 
               TagBox[
                DiskBox[{-0.933, 0.616}, 0.03677664428618335], "DynamicName", 
                BoxID -> "VertexID$8"], 
               TagBox[
                DiskBox[{-0.933, -0.616}, 0.03677664428618335], "DynamicName",
                 BoxID -> "VertexID$9"], 
               TagBox[
                DiskBox[{-1.433, -1.4821}, 0.03677664428618335], 
                "DynamicName", BoxID -> "VertexID$10"], 
               TagBox[
                DiskBox[{-0.567, -1.9821}, 0.03677664428618335], 
                "DynamicName", BoxID -> "VertexID$11"], 
               TagBox[
                DiskBox[{-0.067, -1.116}, 0.03677664428618335], "DynamicName",
                 BoxID -> "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{3.652453104293537, 
              57.41421356237311}, {-62.229606925590026`, \
-0.7037264077432965}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Caveman\"", ",", 
             RowBox[{"{", 
               RowBox[{"3", ",", "4"}], "}"}]}], "}"}]],
        Annotation[#, {"Caveman", {3, 4}}, "Tooltip"]& ],
       TraditionalForm], {195.42857142857142`, -586.2857142857142}, {
      Center, Center}, {359.99999999999994`, 359.99999999999994`}], InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 2, 3, 6, 8, 9, 12, 14, 15, 18, 20, 21, 24}, {{3}, {
                  12}, {3}, {1}, {2}, {4}, {3}, {6}, {6}, {4}, {5}, {7}, {
                  6}, {9}, {9}, {7}, {8}, {10}, {9}, {12}, {12}, {1}, {10}, {
                  11}}}, Pattern}]}, {
              VertexCoordinates -> {{1.3066, -0.5}, {2.1726, 0.}, {1.3066, 
                0.5}, {0.5, 1.3066}, {0., 2.1726}, {-0.5, 1.3066}, {-1.3066, 
                0.5}, {-2.1726, 0.}, {-1.3066, -0.5}, {-0.5, -1.3066}, {
                0., -2.1726}, {0.5, -1.3066}}}]], Typeset`boxes = 
            GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{1.3066, -0.5}, 0.03916720235852193], "DynamicName", 
                BoxID -> "VertexID$1"], 
               TagBox[
                DiskBox[{2.1726, 0.}, 0.03916720235852193], "DynamicName", 
                BoxID -> "VertexID$2"], 
               TagBox[
                DiskBox[{1.3066, 0.5}, 0.03916720235852193], "DynamicName", 
                BoxID -> "VertexID$3"], 
               TagBox[
                DiskBox[{0.5, 1.3066}, 0.03916720235852193], "DynamicName", 
                BoxID -> "VertexID$4"], 
               TagBox[
                DiskBox[{0., 2.1726}, 0.03916720235852193], "DynamicName", 
                BoxID -> "VertexID$5"], 
               TagBox[
                DiskBox[{-0.5, 1.3066}, 0.03916720235852193], "DynamicName", 
                BoxID -> "VertexID$6"], 
               TagBox[
                DiskBox[{-1.3066, 0.5}, 0.03916720235852193], "DynamicName", 
                BoxID -> "VertexID$7"], 
               TagBox[
                DiskBox[{-2.1726, 0.}, 0.03916720235852193], "DynamicName", 
                BoxID -> "VertexID$8"], 
               TagBox[
                DiskBox[{-1.3066, -0.5}, 0.03916720235852193], "DynamicName", 
                BoxID -> "VertexID$9"], 
               TagBox[
                DiskBox[{-0.5, -1.3066}, 0.03916720235852193], "DynamicName", 
                BoxID -> "VertexID$10"], 
               TagBox[
                DiskBox[{0., -2.1726}, 0.03916720235852193], "DynamicName", 
                BoxID -> "VertexID$11"], 
               TagBox[
                DiskBox[{0.5, -1.3066}, 0.03916720235852193], "DynamicName", 
                BoxID -> "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{0.22133333333333027`, 
              60.84533333333334}, {-61.77866666666666, \
-1.1546666666666638`}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Caveman\"", ",", 
             RowBox[{"{", 
               RowBox[{"4", ",", "3"}], "}"}]}], "}"}]],
        Annotation[#, {"Caveman", {4, 3}}, "Tooltip"]& ],
       TraditionalForm], {586.2857142857142, -586.2857142857142}, {
      Center, Center}, {359.99999999999994`, 359.99999999999994`}], InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 10, 20, 22, 24, 26, 28, 30, 32, 34, 36, 38, 40}, {{
                  3}, {4}, {5}, {6}, {7}, {8}, {9}, {10}, {11}, {12}, {3}, {
                  4}, {5}, {6}, {7}, {8}, {9}, {10}, {11}, {12}, {1}, {2}, {
                  1}, {2}, {1}, {2}, {1}, {2}, {1}, {2}, {1}, {2}, {1}, {2}, {
                  1}, {2}, {1}, {2}, {1}, {2}}}, Pattern}]}, {
              VertexCoordinates -> {{1., -0.5}, {1., 0.5}, {2., -4.5}, {
                2., -3.5}, {2., -2.5}, {2., -1.5}, {2., -0.5}, {2., 0.5}, {2.,
                 1.5}, {2., 2.5}, {2., 3.5}, {2., 4.5}}}]], Typeset`boxes = 
            GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{1., -0.5}, 0.061894273127753294`], "DynamicName", 
                BoxID -> "VertexID$1"], 
               TagBox[
                DiskBox[{1., 0.5}, 0.061894273127753294`], "DynamicName", 
                BoxID -> "VertexID$2"], 
               TagBox[
                DiskBox[{2., -4.5}, 0.061894273127753294`], "DynamicName", 
                BoxID -> "VertexID$3"], 
               TagBox[
                DiskBox[{2., -3.5}, 0.061894273127753294`], "DynamicName", 
                BoxID -> "VertexID$4"], 
               TagBox[
                DiskBox[{2., -2.5}, 0.061894273127753294`], "DynamicName", 
                BoxID -> "VertexID$5"], 
               TagBox[
                DiskBox[{2., -1.5}, 0.061894273127753294`], "DynamicName", 
                BoxID -> "VertexID$6"], 
               TagBox[
                DiskBox[{2., -0.5}, 0.061894273127753294`], "DynamicName", 
                BoxID -> "VertexID$7"], 
               TagBox[
                DiskBox[{2., 0.5}, 0.061894273127753294`], "DynamicName", 
                BoxID -> "VertexID$8"], 
               TagBox[
                DiskBox[{2., 1.5}, 0.061894273127753294`], "DynamicName", 
                BoxID -> "VertexID$9"], 
               TagBox[
                DiskBox[{2., 2.5}, 0.061894273127753294`], "DynamicName", 
                BoxID -> "VertexID$10"], 
               TagBox[
                DiskBox[{2., 3.5}, 0.061894273127753294`], "DynamicName", 
                BoxID -> "VertexID$11"], 
               TagBox[
                DiskBox[{2., 4.5}, 0.061894273127753294`], "DynamicName", 
                BoxID -> "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{25.585786437626904`, 
              35.480880229039784`}, {-62.74830333753284, \
-0.18502999580047685`}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"CompleteBipartite\"", ",", 
             RowBox[{"{", 
               RowBox[{"2", ",", "10"}], "}"}]}], "}"}]],
        Annotation[#, {"CompleteBipartite", {2, 10}}, "Tooltip"]& ],
       TraditionalForm], {977.1428571428571, -586.2857142857142}, {
      Center, Center}, {360., 359.99999999999994`}], InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 33, 36}, {{2}, {
                  3}, {4}, {1}, {3}, {4}, {1}, {2}, {5}, {1}, {2}, {5}, {3}, {
                  4}, {6}, {5}, {7}, {8}, {6}, {8}, {9}, {6}, {7}, {10}, {
                  7}, {11}, {12}, {8}, {11}, {12}, {9}, {10}, {12}, {9}, {
                  10}, {11}}}, Pattern}]}, {
              VertexCoordinates -> {{1., 1.}, {2., 2.}, {3., 1.}, {1., 3.}, {
                3., 3.}, {4., 4.}, {4., 5.}, {5., 4.}, {4., 6.}, {6., 4.}, {
                6., 6.}, {5., 5.}}}]], Typeset`boxes = GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{1., 1.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$1"], 
               TagBox[
                DiskBox[{2., 2.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$2"], 
               TagBox[
                DiskBox[{3., 1.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$3"], 
               TagBox[
                DiskBox[{1., 3.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$4"], 
               TagBox[
                DiskBox[{3., 3.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$5"], 
               TagBox[
                DiskBox[{4., 4.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$6"], 
               TagBox[
                DiskBox[{4., 5.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$7"], 
               TagBox[
                DiskBox[{5., 4.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$8"], 
               TagBox[
                DiskBox[{4., 6.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$9"], 
               TagBox[
                DiskBox[{6., 4.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$10"], 
               TagBox[
                DiskBox[{6., 6.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$11"], 
               TagBox[
                DiskBox[{5., 5.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$2", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{-0.4142135623730949, 
              61.25954689570649}, {-62.19288022903979, \
-0.5857864376269033}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Cubic\"", ",", 
             RowBox[{"{", 
               RowBox[{"12", ",", "1"}], "}"}]}], "}"}]],
        Annotation[#, {"Cubic", {12, 1}}, "Tooltip"]& ],
       TraditionalForm], {1368., -586.2857142857142}, {
      Center, Center}, {360.0000000000002, 359.99999999999994`}], InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 33, 36}, {{2}, {
                  3}, {4}, {1}, {3}, {4}, {1}, {2}, {5}, {1}, {2}, {5}, {3}, {
                  4}, {6}, {5}, {7}, {8}, {6}, {9}, {10}, {6}, {9}, {11}, {
                  7}, {8}, {12}, {7}, {11}, {12}, {8}, {10}, {12}, {9}, {
                  10}, {11}}}, Pattern}]}, {
              VertexCoordinates -> {{3., 7.}, {3., 6.}, {1., 6.}, {5., 6.}, {
                3., 5.}, {3., 4.}, {1., 4.}, {5., 4.}, {3., 3.}, {1., 1.}, {
                5., 1.}, {3., 2.}}}]], Typeset`boxes = GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{3., 7.}, 0.04847715736040609], "DynamicName", BoxID -> 
                "VertexID$1"], 
               TagBox[
                DiskBox[{3., 6.}, 0.04847715736040609], "DynamicName", BoxID -> 
                "VertexID$2"], 
               TagBox[
                DiskBox[{1., 6.}, 0.04847715736040609], "DynamicName", BoxID -> 
                "VertexID$3"], 
               TagBox[
                DiskBox[{5., 6.}, 0.04847715736040609], "DynamicName", BoxID -> 
                "VertexID$4"], 
               TagBox[
                DiskBox[{3., 5.}, 0.04847715736040609], "DynamicName", BoxID -> 
                "VertexID$5"], 
               TagBox[
                DiskBox[{3., 4.}, 0.04847715736040609], "DynamicName", BoxID -> 
                "VertexID$6"], 
               TagBox[
                DiskBox[{1., 4.}, 0.04847715736040609], "DynamicName", BoxID -> 
                "VertexID$7"], 
               TagBox[
                DiskBox[{5., 4.}, 0.04847715736040609], "DynamicName", BoxID -> 
                "VertexID$8"], 
               TagBox[
                DiskBox[{3., 3.}, 0.04847715736040609], "DynamicName", BoxID -> 
                "VertexID$9"], 
               TagBox[
                DiskBox[{1., 1.}, 0.04847715736040609], "DynamicName", BoxID -> 
                "VertexID$10"], 
               TagBox[
                DiskBox[{5., 1.}, 0.04847715736040609], "DynamicName", BoxID -> 
                "VertexID$11"], 
               TagBox[
                DiskBox[{3., 2.}, 0.04847715736040609], "DynamicName", BoxID -> 
                "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$2", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{9.138762207271004, 
              52.41421356237309}, {-62.61499925982553, \
-0.3183340735078133}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Cubic\"", ",", 
             RowBox[{"{", 
               RowBox[{"12", ",", "2"}], "}"}]}], "}"}]],
        Annotation[#, {"Cubic", {12, 2}}, "Tooltip"]& ],
       TraditionalForm], {1758.8571428571427`, -586.2857142857142}, {
      Center, Center}, {360.0000000000002, 359.99999999999994`}], InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 33, 36}, {{2}, {
                  3}, {4}, {1}, {3}, {4}, {1}, {2}, {5}, {1}, {2}, {5}, {3}, {
                  4}, {6}, {5}, {7}, {8}, {6}, {9}, {10}, {6}, {11}, {12}, {
                  7}, {10}, {11}, {7}, {9}, {12}, {8}, {9}, {12}, {8}, {10}, {
                  11}}}, Pattern}]}, {
              VertexCoordinates -> {{1., 1.}, {2., 2.}, {3., 1.}, {1., 3.}, {
                3., 3.}, {4., 4.}, {5., 3.}, {3., 5.}, {5., 4.}, {6., 4.}, {
                4., 5.}, {4., 6.}}}]], Typeset`boxes = GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{1., 1.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$1"], 
               TagBox[
                DiskBox[{2., 2.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$2"], 
               TagBox[
                DiskBox[{3., 1.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$3"], 
               TagBox[
                DiskBox[{1., 3.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$4"], 
               TagBox[
                DiskBox[{3., 3.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$5"], 
               TagBox[
                DiskBox[{4., 4.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$6"], 
               TagBox[
                DiskBox[{5., 3.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$7"], 
               TagBox[
                DiskBox[{3., 5.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$8"], 
               TagBox[
                DiskBox[{5., 4.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$9"], 
               TagBox[
                DiskBox[{6., 4.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$10"], 
               TagBox[
                DiskBox[{4., 5.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$11"], 
               TagBox[
                DiskBox[{4., 6.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$2", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{-0.4142135623730949, 
              61.25954689570641}, {-62.192880229039744`, \
-0.5857864376269033}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Cubic\"", ",", 
             RowBox[{"{", 
               RowBox[{"12", ",", "3"}], "}"}]}], "}"}]],
        Annotation[#, {"Cubic", {12, 3}}, "Tooltip"]& ],
       TraditionalForm], {2149.7142857142853`, -586.2857142857142}, {
      Center, Center}, {359.9999999999998, 359.99999999999994`}]}, {InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 33, 36}, {{2}, {
                  3}, {4}, {1}, {3}, {4}, {1}, {2}, {5}, {1}, {2}, {6}, {3}, {
                  6}, {7}, {4}, {5}, {8}, {5}, {8}, {9}, {6}, {7}, {10}, {
                  7}, {11}, {12}, {8}, {11}, {12}, {9}, {10}, {12}, {9}, {
                  10}, {11}}}, Pattern}]}, {
              VertexCoordinates -> {{0.866, 0.5}, {0.5, 0.866}, {0., 1.}, {1.,
                 0.}, {-0.5, 0.866}, {0.866, -0.5}, {-0.866, 0.5}, {
                0.5, -0.866}, {-1., 0.}, {
                0., -1.}, {-0.866, -0.5}, {-0.5, -0.866}}}]], Typeset`boxes = 
            GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{0.866, 0.5}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$1"], 
               TagBox[
                DiskBox[{0.5, 0.866}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$2"], 
               TagBox[
                DiskBox[{0., 1.}, 0.02261146496815286], "DynamicName", BoxID -> 
                "VertexID$3"], 
               TagBox[
                DiskBox[{1., 0.}, 0.02261146496815286], "DynamicName", BoxID -> 
                "VertexID$4"], 
               TagBox[
                DiskBox[{-0.5, 0.866}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$5"], 
               TagBox[
                DiskBox[{0.866, -0.5}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$6"], 
               TagBox[
                DiskBox[{-0.866, 0.5}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$7"], 
               TagBox[
                DiskBox[{0.5, -0.866}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$8"], 
               TagBox[
                DiskBox[{-1., 0.}, 0.02261146496815286], "DynamicName", BoxID -> 
                "VertexID$9"], 
               TagBox[
                DiskBox[{0., -1.}, 0.02261146496815286], "DynamicName", BoxID -> 
                "VertexID$10"], 
               TagBox[
                DiskBox[{-0.866, -0.5}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$11"], 
               TagBox[
                DiskBox[{-0.5, -0.866}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$2", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{0.22133333333333471`, 
              60.84533333333333}, {-61.778666666666666`, \
-1.1546666666666425`}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Cubic\"", ",", 
             RowBox[{"{", 
               RowBox[{"12", ",", "5"}], "}"}]}], "}"}]],
        Annotation[#, {"Cubic", {12, 5}}, "Tooltip"]& ],
       TraditionalForm], {195.42857142857142`, -977.1428571428571}, {
      Center, Center}, {359.99999999999994`, 360.}], InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 33, 36}, {{2}, {
                  3}, {4}, {1}, {3}, {4}, {1}, {2}, {5}, {1}, {2}, {6}, {3}, {
                  6}, {7}, {4}, {5}, {8}, {5}, {9}, {10}, {6}, {9}, {11}, {
                  7}, {8}, {12}, {7}, {11}, {12}, {8}, {10}, {12}, {9}, {
                  10}, {11}}}, Pattern}]}, {
              VertexCoordinates -> {{1., 1.}, {2., 2.}, {3., 1.}, {1., 3.}, {
                4., 1.}, {1., 4.}, {5., 1.}, {1., 5.}, {3., 3.}, {5., 4.}, {
                4., 5.}, {4., 4.}}}]], Typeset`boxes = GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{1., 1.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$1"], 
               TagBox[
                DiskBox[{2., 2.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$2"], 
               TagBox[
                DiskBox[{3., 1.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$3"], 
               TagBox[
                DiskBox[{1., 3.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$4"], 
               TagBox[
                DiskBox[{4., 1.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$5"], 
               TagBox[
                DiskBox[{1., 4.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$6"], 
               TagBox[
                DiskBox[{5., 1.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$7"], 
               TagBox[
                DiskBox[{1., 5.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$8"], 
               TagBox[
                DiskBox[{3., 3.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$9"], 
               TagBox[
                DiskBox[{5., 4.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$10"], 
               TagBox[
                DiskBox[{4., 5.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$11"], 
               TagBox[
                DiskBox[{4., 4.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$2", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{-0.4142135623730949, 
              61.25954689570644}, {-62.19288022903974, \
-0.5857864376269033}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Cubic\"", ",", 
             RowBox[{"{", 
               RowBox[{"12", ",", "6"}], "}"}]}], "}"}]],
        Annotation[#, {"Cubic", {12, 6}}, "Tooltip"]& ],
       TraditionalForm], {586.2857142857142, -977.1428571428571}, {
      Center, Center}, {359.99999999999994`, 360.}], InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 33, 36}, {{2}, {
                  3}, {4}, {1}, {3}, {4}, {1}, {2}, {5}, {1}, {2}, {6}, {3}, {
                  6}, {7}, {4}, {5}, {8}, {5}, {9}, {10}, {6}, {11}, {12}, {
                  7}, {10}, {11}, {7}, {9}, {12}, {8}, {9}, {12}, {8}, {10}, {
                  11}}}, Pattern}]}, {
              VertexCoordinates -> {{3., 5.}, {3., 4.}, {2., 4.}, {4., 4.}, {
                2., 3.}, {4., 3.}, {1., 3.}, {5., 3.}, {1., 1.}, {2., 2.}, {
                5., 1.}, {4., 2.}}}]], Typeset`boxes = GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{3., 5.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$1"], 
               TagBox[
                DiskBox[{3., 4.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$2"], 
               TagBox[
                DiskBox[{2., 4.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$3"], 
               TagBox[
                DiskBox[{4., 4.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$4"], 
               TagBox[
                DiskBox[{2., 3.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$5"], 
               TagBox[
                DiskBox[{4., 3.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$6"], 
               TagBox[
                DiskBox[{1., 3.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$7"], 
               TagBox[
                DiskBox[{5., 3.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$8"], 
               TagBox[
                DiskBox[{1., 1.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$9"], 
               TagBox[
                DiskBox[{2., 2.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$10"], 
               TagBox[
                DiskBox[{5., 1.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$11"], 
               TagBox[
                DiskBox[{4., 2.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$2", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{-0.4142135623730949, 
              61.259546895706464`}, {-62.19288022903975, \
-0.5857864376269033}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Cubic\"", ",", 
             RowBox[{"{", 
               RowBox[{"12", ",", "7"}], "}"}]}], "}"}]],
        Annotation[#, {"Cubic", {12, 7}}, "Tooltip"]& ],
       TraditionalForm], {977.1428571428571, -977.1428571428571}, {
      Center, Center}, {360., 360.}], InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 33, 36}, {{2}, {
                  3}, {4}, {1}, {3}, {4}, {1}, {2}, {5}, {1}, {2}, {6}, {3}, {
                  7}, {8}, {4}, {7}, {8}, {5}, {6}, {9}, {5}, {6}, {10}, {
                  7}, {11}, {12}, {8}, {11}, {12}, {9}, {10}, {12}, {9}, {
                  10}, {11}}}, Pattern}]}, {
              VertexCoordinates -> {{0.866, 0.5}, {0.5, 0.866}, {0., 1.}, {1.,
                 0.}, {-0.5, 0.866}, {0.866, -0.5}, {-0.866, 0.5}, {
                0.5, -0.866}, {-1., 0.}, {
                0., -1.}, {-0.866, -0.5}, {-0.5, -0.866}}}]], Typeset`boxes = 
            GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{0.866, 0.5}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$1"], 
               TagBox[
                DiskBox[{0.5, 0.866}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$2"], 
               TagBox[
                DiskBox[{0., 1.}, 0.02261146496815286], "DynamicName", BoxID -> 
                "VertexID$3"], 
               TagBox[
                DiskBox[{1., 0.}, 0.02261146496815286], "DynamicName", BoxID -> 
                "VertexID$4"], 
               TagBox[
                DiskBox[{-0.5, 0.866}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$5"], 
               TagBox[
                DiskBox[{0.866, -0.5}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$6"], 
               TagBox[
                DiskBox[{-0.866, 0.5}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$7"], 
               TagBox[
                DiskBox[{0.5, -0.866}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$8"], 
               TagBox[
                DiskBox[{-1., 0.}, 0.02261146496815286], "DynamicName", BoxID -> 
                "VertexID$9"], 
               TagBox[
                DiskBox[{0., -1.}, 0.02261146496815286], "DynamicName", BoxID -> 
                "VertexID$10"], 
               TagBox[
                DiskBox[{-0.866, -0.5}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$11"], 
               TagBox[
                DiskBox[{-0.5, -0.866}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$2", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{0.22133333333333427`, 
              
              60.845333333333386`}, {-61.77866666666668, \
-1.1546666666666425`}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Cubic\"", ",", 
             RowBox[{"{", 
               RowBox[{"12", ",", "9"}], "}"}]}], "}"}]],
        Annotation[#, {"Cubic", {12, 9}}, "Tooltip"]& ],
       TraditionalForm], {1368., -977.1428571428571}, {
      Center, Center}, {360.0000000000002, 360.}], InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 33, 36}, {{2}, {
                  3}, {4}, {1}, {3}, {4}, {1}, {2}, {5}, {1}, {2}, {6}, {3}, {
                  7}, {8}, {4}, {7}, {9}, {5}, {6}, {8}, {5}, {7}, {10}, {
                  6}, {11}, {12}, {8}, {11}, {12}, {9}, {10}, {12}, {9}, {
                  10}, {11}}}, Pattern}]}, {
              VertexCoordinates -> {{1., 1.}, {2., 2.}, {1., 2.}, {2., 1.}, {
                1., 3.}, {4., 1.}, {2., 3.}, {2., 4.}, {4., 3.}, {3., 4.}, {
                4., 4.}, {3., 3.}}}]], Typeset`boxes = GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{1., 1.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$1"], 
               TagBox[
                DiskBox[{2., 2.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$2"], 
               TagBox[
                DiskBox[{1., 2.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$3"], 
               TagBox[
                DiskBox[{2., 1.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$4"], 
               TagBox[
                DiskBox[{1., 3.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$5"], 
               TagBox[
                DiskBox[{4., 1.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$6"], 
               TagBox[
                DiskBox[{2., 3.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$7"], 
               TagBox[
                DiskBox[{2., 4.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$8"], 
               TagBox[
                DiskBox[{4., 3.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$9"], 
               TagBox[
                DiskBox[{3., 4.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$10"], 
               TagBox[
                DiskBox[{4., 4.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$11"], 
               TagBox[
                DiskBox[{3., 3.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$2", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{-0.4142135623730949, 
              61.25954689570649}, {-62.19288022903976, \
-0.5857864376269033}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Cubic\"", ",", 
             RowBox[{"{", 
               RowBox[{"12", ",", "10"}], "}"}]}], "}"}]],
        Annotation[#, {"Cubic", {12, 10}}, "Tooltip"]& ],
       TraditionalForm], {1758.8571428571427`, -977.1428571428571}, {
      Center, Center}, {360.0000000000002, 360.}], InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 33, 36}, {{2}, {
                  3}, {4}, {1}, {3}, {4}, {1}, {2}, {5}, {1}, {2}, {6}, {3}, {
                  7}, {8}, {4}, {7}, {9}, {5}, {6}, {10}, {5}, {9}, {11}, {
                  6}, {8}, {12}, {7}, {11}, {12}, {8}, {10}, {12}, {9}, {
                  10}, {11}}}, Pattern}]}, {
              VertexCoordinates -> {{1., 1.}, {2., 2.}, {3., 1.}, {1., 3.}, {
                4., 2.}, {2., 4.}, {3., 3.}, {6., 4.}, {4., 6.}, {4., 4.}, {
                5., 4.}, {4., 5.}}}]], Typeset`boxes = GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{1., 1.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$1"], 
               TagBox[
                DiskBox[{2., 2.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$2"], 
               TagBox[
                DiskBox[{3., 1.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$3"], 
               TagBox[
                DiskBox[{1., 3.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$4"], 
               TagBox[
                DiskBox[{4., 2.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$5"], 
               TagBox[
                DiskBox[{2., 4.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$6"], 
               TagBox[
                DiskBox[{3., 3.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$7"], 
               TagBox[
                DiskBox[{6., 4.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$8"], 
               TagBox[
                DiskBox[{4., 6.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$9"], 
               TagBox[
                DiskBox[{4., 4.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$10"], 
               TagBox[
                DiskBox[{5., 4.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$11"], 
               TagBox[
                DiskBox[{4., 5.}, 0.043048128342245986`], "DynamicName", 
                BoxID -> "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$2", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{-0.4142135623730949, 
              61.25954689570641}, {-62.192880229039744`, \
-0.5857864376269033}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Cubic\"", ",", 
             RowBox[{"{", 
               RowBox[{"12", ",", "11"}], "}"}]}], "}"}]],
        Annotation[#, {"Cubic", {12, 11}}, "Tooltip"]& ],
       TraditionalForm], {2149.7142857142853`, -977.1428571428571}, {
      Center, Center}, {359.9999999999998, 360.}]}, {InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 33, 36}, {{2}, {
                  3}, {4}, {1}, {3}, {4}, {1}, {2}, {5}, {1}, {2}, {6}, {3}, {
                  7}, {8}, {4}, {7}, {9}, {5}, {6}, {10}, {5}, {10}, {11}, {
                  6}, {11}, {12}, {7}, {8}, {12}, {8}, {9}, {12}, {9}, {10}, {
                  11}}}, Pattern}]}, {
              VertexCoordinates -> {{1., 1.}, {2., 2.}, {2., 1.}, {1., 2.}, {
                5., 1.}, {1., 3.}, {3., 2.}, {5., 3.}, {1., 5.}, {3., 3.}, {
                5., 5.}, {3., 4.}}}]], Typeset`boxes = GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{1., 1.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$1"], 
               TagBox[
                DiskBox[{2., 2.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$2"], 
               TagBox[
                DiskBox[{2., 1.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$3"], 
               TagBox[
                DiskBox[{1., 2.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$4"], 
               TagBox[
                DiskBox[{5., 1.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$5"], 
               TagBox[
                DiskBox[{1., 3.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$6"], 
               TagBox[
                DiskBox[{3., 2.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$7"], 
               TagBox[
                DiskBox[{5., 3.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$8"], 
               TagBox[
                DiskBox[{1., 5.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$9"], 
               TagBox[
                DiskBox[{3., 3.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$10"], 
               TagBox[
                DiskBox[{5., 5.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$11"], 
               TagBox[
                DiskBox[{3., 4.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$2", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{-0.4142135623730949, 
              61.25954689570643}, {-62.19288022903971, \
-0.5857864376269033}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Cubic\"", ",", 
             RowBox[{"{", 
               RowBox[{"12", ",", "12"}], "}"}]}], "}"}]],
        Annotation[#, {"Cubic", {12, 12}}, "Tooltip"]& ],
       TraditionalForm], {195.42857142857142`, -1368.}, {
      Center, Center}, {359.99999999999994`, 360.0000000000002}], InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 33, 36}, {{2}, {
                  3}, {4}, {1}, {3}, {4}, {1}, {2}, {5}, {1}, {2}, {6}, {3}, {
                  7}, {8}, {4}, {9}, {10}, {5}, {8}, {9}, {5}, {7}, {11}, {
                  6}, {7}, {12}, {6}, {11}, {12}, {8}, {10}, {12}, {9}, {
                  10}, {11}}}, Pattern}]}, {
              VertexCoordinates -> {{1., 1.}, {2., 2.}, {2., 1.}, {1., 2.}, {
                3., 1.}, {1., 4.}, {3., 2.}, {4., 1.}, {2., 3.}, {3., 4.}, {
                4., 3.}, {3., 3.}}}]], Typeset`boxes = GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{1., 1.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$1"], 
               TagBox[
                DiskBox[{2., 2.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$2"], 
               TagBox[
                DiskBox[{2., 1.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$3"], 
               TagBox[
                DiskBox[{1., 2.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$4"], 
               TagBox[
                DiskBox[{3., 1.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$5"], 
               TagBox[
                DiskBox[{1., 4.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$6"], 
               TagBox[
                DiskBox[{3., 2.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$7"], 
               TagBox[
                DiskBox[{4., 1.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$8"], 
               TagBox[
                DiskBox[{2., 3.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$9"], 
               TagBox[
                DiskBox[{3., 4.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$10"], 
               TagBox[
                DiskBox[{4., 3.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$11"], 
               TagBox[
                DiskBox[{3., 3.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$2", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{-0.4142135623730949, 
              61.25954689570645}, {-62.192880229039716`, \
-0.5857864376269033}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Cubic\"", ",", 
             RowBox[{"{", 
               RowBox[{"12", ",", "14"}], "}"}]}], "}"}]],
        Annotation[#, {"Cubic", {12, 14}}, "Tooltip"]& ],
       TraditionalForm], {586.2857142857142, -1368.}, {
      Center, Center}, {359.99999999999994`, 360.0000000000002}], InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 33, 36}, {{2}, {
                  3}, {4}, {1}, {3}, {4}, {1}, {2}, {5}, {1}, {2}, {6}, {3}, {
                  7}, {8}, {4}, {9}, {10}, {5}, {8}, {11}, {5}, {7}, {11}, {
                  6}, {10}, {12}, {6}, {9}, {12}, {7}, {8}, {12}, {9}, {10}, {
                  11}}}, Pattern}]}, {
              VertexCoordinates -> {{0.866, 0.5}, {0.5, 0.866}, {0., 1.}, {1.,
                 0.}, {-0.5, 0.866}, {0.866, -0.5}, {-0.866, 0.5}, {-1., 
                0.}, {0., -1.}, {
                0.5, -0.866}, {-0.866, -0.5}, {-0.5, -0.866}}}]], 
            Typeset`boxes = GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{0.866, 0.5}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$1"], 
               TagBox[
                DiskBox[{0.5, 0.866}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$2"], 
               TagBox[
                DiskBox[{0., 1.}, 0.02261146496815286], "DynamicName", BoxID -> 
                "VertexID$3"], 
               TagBox[
                DiskBox[{1., 0.}, 0.02261146496815286], "DynamicName", BoxID -> 
                "VertexID$4"], 
               TagBox[
                DiskBox[{-0.5, 0.866}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$5"], 
               TagBox[
                DiskBox[{0.866, -0.5}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$6"], 
               TagBox[
                DiskBox[{-0.866, 0.5}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$7"], 
               TagBox[
                DiskBox[{-1., 0.}, 0.02261146496815286], "DynamicName", BoxID -> 
                "VertexID$8"], 
               TagBox[
                DiskBox[{0., -1.}, 0.02261146496815286], "DynamicName", BoxID -> 
                "VertexID$9"], 
               TagBox[
                DiskBox[{0.5, -0.866}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$10"], 
               TagBox[
                DiskBox[{-0.866, -0.5}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$11"], 
               TagBox[
                DiskBox[{-0.5, -0.866}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$2", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{0.22133333333334004`, 
              60.84533333333336}, {-61.77866666666664, \
-1.1546666666666425`}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Cubic\"", ",", 
             RowBox[{"{", 
               RowBox[{"12", ",", "15"}], "}"}]}], "}"}]],
        Annotation[#, {"Cubic", {12, 15}}, "Tooltip"]& ],
       TraditionalForm], {977.1428571428571, -1368.}, {
      Center, Center}, {360., 360.0000000000002}], InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 33, 36}, {{2}, {
                  3}, {4}, {1}, {3}, {4}, {1}, {2}, {5}, {1}, {2}, {6}, {3}, {
                  7}, {8}, {4}, {9}, {10}, {5}, {8}, {11}, {5}, {7}, {12}, {
                  6}, {10}, {11}, {6}, {9}, {12}, {7}, {9}, {12}, {8}, {10}, {
                  11}}}, Pattern}]}, {
              VertexCoordinates -> {{1., 1.}, {2., 2.}, {2., 1.}, {1., 2.}, {
                3., 1.}, {1., 3.}, {3., 2.}, {4., 2.}, {2., 3.}, {2., 4.}, {
                3., 3.}, {4., 4.}}}]], Typeset`boxes = GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{1., 1.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$1"], 
               TagBox[
                DiskBox[{2., 2.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$2"], 
               TagBox[
                DiskBox[{2., 1.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$3"], 
               TagBox[
                DiskBox[{1., 2.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$4"], 
               TagBox[
                DiskBox[{3., 1.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$5"], 
               TagBox[
                DiskBox[{1., 3.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$6"], 
               TagBox[
                DiskBox[{3., 2.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$7"], 
               TagBox[
                DiskBox[{4., 2.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$8"], 
               TagBox[
                DiskBox[{2., 3.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$9"], 
               TagBox[
                DiskBox[{2., 4.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$10"], 
               TagBox[
                DiskBox[{3., 3.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$11"], 
               TagBox[
                DiskBox[{4., 4.}, 0.030239520958083826`], "DynamicName", 
                BoxID -> "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$2", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{-0.4142135623730949, 
              61.25954689570648}, {-62.19288022903977, \
-0.5857864376269033}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Cubic\"", ",", 
             RowBox[{"{", 
               RowBox[{"12", ",", "16"}], "}"}]}], "}"}]],
        Annotation[#, {"Cubic", {12, 16}}, "Tooltip"]& ],
       TraditionalForm], {1368., -1368.}, {
      Center, Center}, {360.0000000000002, 360.0000000000002}], InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 33, 36}, {{2}, {
                  3}, {4}, {1}, {3}, {4}, {1}, {2}, {5}, {1}, {2}, {6}, {3}, {
                  7}, {8}, {4}, {9}, {10}, {5}, {9}, {11}, {5}, {10}, {11}, {
                  6}, {7}, {12}, {6}, {8}, {12}, {7}, {8}, {12}, {9}, {10}, {
                  11}}}, Pattern}]}, {
              VertexCoordinates -> {{1., 1.}, {2., 2.}, {2., 1.}, {1., 2.}, {
                3., 1.}, {1., 3.}, {5., 3.}, {3., 2.}, {3., 5.}, {2., 3.}, {
                4., 3.}, {3., 4.}}}]], Typeset`boxes = GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{1., 1.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$1"], 
               TagBox[
                DiskBox[{2., 2.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$2"], 
               TagBox[
                DiskBox[{2., 1.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$3"], 
               TagBox[
                DiskBox[{1., 2.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$4"], 
               TagBox[
                DiskBox[{3., 1.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$5"], 
               TagBox[
                DiskBox[{1., 3.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$6"], 
               TagBox[
                DiskBox[{5., 3.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$7"], 
               TagBox[
                DiskBox[{3., 2.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$8"], 
               TagBox[
                DiskBox[{3., 5.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$9"], 
               TagBox[
                DiskBox[{2., 3.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$10"], 
               TagBox[
                DiskBox[{4., 3.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$11"], 
               TagBox[
                DiskBox[{3., 4.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$2", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{-0.4142135623730949, 
              61.259546895706464`}, {-62.192880229039744`, \
-0.5857864376269033}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Cubic\"", ",", 
             RowBox[{"{", 
               RowBox[{"12", ",", "19"}], "}"}]}], "}"}]],
        Annotation[#, {"Cubic", {12, 19}}, "Tooltip"]& ],
       TraditionalForm], {1758.8571428571427`, -1368.}, {
      Center, Center}, {360.0000000000002, 360.0000000000002}], InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 33, 36}, {{2}, {
                  3}, {4}, {1}, {3}, {4}, {1}, {2}, {5}, {1}, {2}, {6}, {3}, {
                  7}, {8}, {4}, {9}, {10}, {5}, {9}, {11}, {5}, {10}, {12}, {
                  6}, {7}, {11}, {6}, {8}, {12}, {7}, {9}, {12}, {8}, {10}, {
                  11}}}, Pattern}]}, {
              VertexCoordinates -> {{1., 1.}, {2., 2.}, {2., 1.}, {1., 2.}, {
                5., 1.}, {1., 5.}, {5., 4.}, {3., 2.}, {4., 5.}, {2., 3.}, {
                4., 4.}, {3., 3.}}}]], Typeset`boxes = GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{1., 1.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$1"], 
               TagBox[
                DiskBox[{2., 2.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$2"], 
               TagBox[
                DiskBox[{2., 1.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$3"], 
               TagBox[
                DiskBox[{1., 2.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$4"], 
               TagBox[
                DiskBox[{5., 1.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$5"], 
               TagBox[
                DiskBox[{1., 5.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$6"], 
               TagBox[
                DiskBox[{5., 4.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$7"], 
               TagBox[
                DiskBox[{3., 2.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$8"], 
               TagBox[
                DiskBox[{4., 5.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$9"], 
               TagBox[
                DiskBox[{2., 3.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$10"], 
               TagBox[
                DiskBox[{4., 4.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$11"], 
               TagBox[
                DiskBox[{3., 3.}, 0.03700564971751412], "DynamicName", BoxID -> 
                "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$2", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{-0.4142135623730949, 
              61.259546895706414`}, {-62.19288022903971, \
-0.5857864376269033}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Cubic\"", ",", 
             RowBox[{"{", 
               RowBox[{"12", ",", "20"}], "}"}]}], "}"}]],
        Annotation[#, {"Cubic", {12, 20}}, "Tooltip"]& ],
       TraditionalForm], {2149.7142857142853`, -1368.}, {
      Center, Center}, {359.9999999999998, 360.0000000000002}]}, {InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 33, 36}, {{2}, {
                  3}, {4}, {1}, {3}, {5}, {1}, {2}, {6}, {1}, {5}, {6}, {2}, {
                  4}, {7}, {3}, {4}, {8}, {5}, {9}, {10}, {6}, {9}, {11}, {
                  7}, {8}, {12}, {7}, {11}, {12}, {8}, {10}, {12}, {9}, {
                  10}, {11}}}, Pattern}]}, {
              VertexCoordinates -> {{0.866, 0.5}, {0.5, 0.866}, {0., 1.}, {1.,
                 0.}, {0.866, -0.5}, {-0.5, 0.866}, {0.5, -0.866}, {-0.866, 
                0.5}, {-1., 0.}, {
                0., -1.}, {-0.5, -0.866}, {-0.866, -0.5}}}]], Typeset`boxes = 
            GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{0.866, 0.5}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$1"], 
               TagBox[
                DiskBox[{0.5, 0.866}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$2"], 
               TagBox[
                DiskBox[{0., 1.}, 0.02261146496815286], "DynamicName", BoxID -> 
                "VertexID$3"], 
               TagBox[
                DiskBox[{1., 0.}, 0.02261146496815286], "DynamicName", BoxID -> 
                "VertexID$4"], 
               TagBox[
                DiskBox[{0.866, -0.5}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$5"], 
               TagBox[
                DiskBox[{-0.5, 0.866}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$6"], 
               TagBox[
                DiskBox[{0.5, -0.866}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$7"], 
               TagBox[
                DiskBox[{-0.866, 0.5}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$8"], 
               TagBox[
                DiskBox[{-1., 0.}, 0.02261146496815286], "DynamicName", BoxID -> 
                "VertexID$9"], 
               TagBox[
                DiskBox[{0., -1.}, 0.02261146496815286], "DynamicName", BoxID -> 
                "VertexID$10"], 
               TagBox[
                DiskBox[{-0.5, -0.866}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$11"], 
               TagBox[
                DiskBox[{-0.866, -0.5}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$2", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{0.22133333333333471`, 
              60.84533333333333}, {-61.77866666666664, \
-1.1546666666666425`}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Cubic\"", ",", 
             RowBox[{"{", 
               RowBox[{"12", ",", "23"}], "}"}]}], "}"}]],
        Annotation[#, {"Cubic", {12, 23}}, "Tooltip"]& ],
       TraditionalForm], {195.42857142857142`, -1758.8571428571427`}, {
      Center, Center}, {359.99999999999994`, 360.0000000000002}], InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 33, 36}, {{2}, {
                  3}, {4}, {1}, {3}, {5}, {1}, {2}, {6}, {1}, {5}, {6}, {2}, {
                  4}, {7}, {3}, {4}, {8}, {5}, {9}, {10}, {6}, {11}, {12}, {
                  7}, {10}, {11}, {7}, {9}, {12}, {8}, {9}, {12}, {8}, {10}, {
                  11}}}, Pattern}]}]], Typeset`boxes = GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{0., 0.9443927536210082}, 0.036887472427263285`], 
                "DynamicName", BoxID -> "VertexID$1"], 
               TagBox[
                
                DiskBox[{0.4927810948108542, 1.4322983584421234`}, 
                 0.036887472427263285`], "DynamicName", BoxID -> 
                "VertexID$2"], 
               TagBox[
                
                DiskBox[{0.46507411485303063`, 0.4318300914912726}, 
                 0.036887472427263285`], "DynamicName", BoxID -> 
                "VertexID$3"], 
               TagBox[
                
                DiskBox[{0.9974987747424742, 0.9249739541722032}, 
                 0.036887472427263285`], "DynamicName", BoxID -> 
                "VertexID$4"], 
               TagBox[
                
                DiskBox[{1.5963627647234047`, 1.6970832259938164`}, 
                 0.036887472427263285`], "DynamicName", BoxID -> 
                "VertexID$5"], 
               TagBox[
                
                DiskBox[{1.5492064364185523`, 0.1281412859049732}, 
                 0.036887472427263285`], "DynamicName", BoxID -> 
                "VertexID$6"], 
               TagBox[
                
                DiskBox[{2.9657986508645746`, 1.7960314541520366`}, 
                 0.036887472427263285`], "DynamicName", BoxID -> 
                "VertexID$7"], 
               TagBox[
                DiskBox[{2.896709927986951, 0.}, 0.036887472427263285`], 
                "DynamicName", BoxID -> "VertexID$8"], 
               TagBox[
                
                DiskBox[{3.981507459144219, 1.2105746478963693`}, 
                 0.036887472427263285`], "DynamicName", BoxID -> 
                "VertexID$9"], 
               TagBox[
                
                DiskBox[{3.802452497009604, 1.6742592227824729`}, 
                 0.036887472427263285`], "DynamicName", BoxID -> 
                "VertexID$10"], 
               TagBox[
                
                DiskBox[{3.929310596393738, 0.1713922797063243}, 
                 0.036887472427263285`], "DynamicName", BoxID -> 
                "VertexID$11"], 
               TagBox[
                
                DiskBox[{3.642192078193337, 0.628371375320155}, 
                 0.036887472427263285`], "DynamicName", BoxID -> 
                "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$2", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             ImageSizeCache->{{-0.144393151139373, 
              61.211059817806024`}, {-46.347546895706344`, \
-16.585786437626904`}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Cubic\"", ",", 
             RowBox[{"{", 
               RowBox[{"12", ",", "24"}], "}"}]}], "}"}]],
        Annotation[#, {"Cubic", {12, 24}}, "Tooltip"]& ],
       TraditionalForm], {586.2857142857142, -1758.8571428571427`}, {
      Center, Center}, {359.99999999999994`, 360.0000000000002}], InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 33, 36}, {{2}, {
                  3}, {4}, {1}, {3}, {5}, {1}, {2}, {6}, {1}, {5}, {7}, {2}, {
                  4}, {7}, {3}, {8}, {9}, {4}, {5}, {10}, {6}, {9}, {11}, {
                  6}, {8}, {12}, {7}, {11}, {12}, {8}, {10}, {12}, {9}, {
                  10}, {11}}}, Pattern}]}, {
              VertexCoordinates -> {{0.866, 0.5}, {0.5, 0.866}, {0., 1.}, {1.,
                 0.}, {0.866, -0.5}, {-0.5, 0.866}, {0.5, -0.866}, {-0.866, 
                0.5}, {-1., 0.}, {
                0., -1.}, {-0.5, -0.866}, {-0.866, -0.5}}}]], Typeset`boxes = 
            GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{0.866, 0.5}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$1"], 
               TagBox[
                DiskBox[{0.5, 0.866}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$2"], 
               TagBox[
                DiskBox[{0., 1.}, 0.02261146496815286], "DynamicName", BoxID -> 
                "VertexID$3"], 
               TagBox[
                DiskBox[{1., 0.}, 0.02261146496815286], "DynamicName", BoxID -> 
                "VertexID$4"], 
               TagBox[
                DiskBox[{0.866, -0.5}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$5"], 
               TagBox[
                DiskBox[{-0.5, 0.866}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$6"], 
               TagBox[
                DiskBox[{0.5, -0.866}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$7"], 
               TagBox[
                DiskBox[{-0.866, 0.5}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$8"], 
               TagBox[
                DiskBox[{-1., 0.}, 0.02261146496815286], "DynamicName", BoxID -> 
                "VertexID$9"], 
               TagBox[
                DiskBox[{0., -1.}, 0.02261146496815286], "DynamicName", BoxID -> 
                "VertexID$10"], 
               TagBox[
                DiskBox[{-0.5, -0.866}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$11"], 
               TagBox[
                DiskBox[{-0.866, -0.5}, 0.02261146496815286], "DynamicName", 
                BoxID -> "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$2", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{0.22133333333334004`, 
              60.84533333333336}, {-61.77866666666664, \
-1.1546666666666425`}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Cubic\"", ",", 
             RowBox[{"{", 
               RowBox[{"12", ",", "26"}], "}"}]}], "}"}]],
        Annotation[#, {"Cubic", {12, 26}}, "Tooltip"]& ],
       TraditionalForm], {977.1428571428571, -1758.8571428571427`}, {
      Center, Center}, {360., 360.0000000000002}], InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 33, 36}, {{2}, {
                  3}, {4}, {1}, {3}, {5}, {1}, {2}, {6}, {1}, {5}, {7}, {2}, {
                  4}, {8}, {3}, {7}, {9}, {4}, {6}, {10}, {5}, {9}, {11}, {
                  6}, {8}, {12}, {7}, {11}, {12}, {8}, {10}, {12}, {9}, {
                  10}, {11}}}, Pattern}]}, {
              VertexCoordinates -> {{1283., 699.}, {1399., 252.}, {894., 
                447.}, {1556., 757.}, {2020., 310.}, {0., 0.}, {1365., 
                1576.}, {3105., 542.}, {4321., 0.}, {2539., 1672.}, {2974., 
                1302.}, {3278., 1889.}}}]], Typeset`boxes = GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{1283., 699.}, 0.14953860705469812`], "DynamicName", 
                BoxID -> "VertexID$1"], 
               TagBox[
                DiskBox[{1399., 252.}, 0.14953860705469812`], "DynamicName", 
                BoxID -> "VertexID$2"], 
               TagBox[
                DiskBox[{894., 447.}, 0.14953860705469812`], "DynamicName", 
                BoxID -> "VertexID$3"], 
               TagBox[
                DiskBox[{1556., 757.}, 0.14953860705469812`], "DynamicName", 
                BoxID -> "VertexID$4"], 
               TagBox[
                DiskBox[{2020., 310.}, 0.14953860705469812`], "DynamicName", 
                BoxID -> "VertexID$5"], 
               TagBox[
                DiskBox[{0., 0.}, 0.14953860705469812`], "DynamicName", BoxID -> 
                "VertexID$6"], 
               TagBox[
                DiskBox[{1365., 1576.}, 0.14953860705469812`], "DynamicName", 
                BoxID -> "VertexID$7"], 
               TagBox[
                DiskBox[{3105., 542.}, 0.14953860705469812`], "DynamicName", 
                BoxID -> "VertexID$8"], 
               TagBox[
                DiskBox[{4321., 0.}, 0.14953860705469812`], "DynamicName", 
                BoxID -> "VertexID$9"], 
               TagBox[
                DiskBox[{2539., 1672.}, 0.14953860705469812`], "DynamicName", 
                BoxID -> "VertexID$10"], 
               TagBox[
                DiskBox[{2974., 1302.}, 0.14953860705469812`], "DynamicName", 
                BoxID -> "VertexID$11"], 
               TagBox[
                DiskBox[{3278., 1889.}, 0.14953860705469812`], "DynamicName", 
                BoxID -> "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$2", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{-0.4142135623730958, 
              61.25954689570648}, {-45.69627059239366, \
-16.585786437626904`}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Cubic\"", ",", 
             RowBox[{"{", 
               RowBox[{"12", ",", "28"}], "}"}]}], "}"}]],
        Annotation[#, {"Cubic", {12, 28}}, "Tooltip"]& ],
       TraditionalForm], {1368., -1758.8571428571427`}, {
      Center, Center}, {360.0000000000002, 360.0000000000002}], InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 33, 36}, {{2}, {
                  3}, {4}, {1}, {3}, {5}, {1}, {2}, {6}, {1}, {5}, {7}, {2}, {
                  4}, {8}, {3}, {7}, {9}, {4}, {6}, {10}, {5}, {10}, {11}, {
                  6}, {11}, {12}, {7}, {8}, {12}, {8}, {9}, {12}, {9}, {10}, {
                  11}}}, Pattern}]}, {
              VertexCoordinates -> {{1103., 594.}, {1189., 212.}, {764., 
                382.}, {1356., 637.}, {1700., 255.}, {0., 0.}, {1265., 
                1396.}, {2555., 427.}, {4526., 0.}, {2439., 1442.}, {3526., 
                485.}, {3497., 1500.}}}]], Typeset`boxes = 
            GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{1103., 594.}, 0.14955944225389342`], "DynamicName", 
                BoxID -> "VertexID$1"], 
               TagBox[
                DiskBox[{1189., 212.}, 0.14955944225389342`], "DynamicName", 
                BoxID -> "VertexID$2"], 
               TagBox[
                DiskBox[{764., 382.}, 0.14955944225389342`], "DynamicName", 
                BoxID -> "VertexID$3"], 
               TagBox[
                DiskBox[{1356., 637.}, 0.14955944225389342`], "DynamicName", 
                BoxID -> "VertexID$4"], 
               TagBox[
                DiskBox[{1700., 255.}, 0.14955944225389342`], "DynamicName", 
                BoxID -> "VertexID$5"], 
               TagBox[
                DiskBox[{0., 0.}, 0.14955944225389342`], "DynamicName", BoxID -> 
                "VertexID$6"], 
               TagBox[
                DiskBox[{1265., 1396.}, 0.14955944225389342`], "DynamicName", 
                BoxID -> "VertexID$7"], 
               TagBox[
                DiskBox[{2555., 427.}, 0.14955944225389342`], "DynamicName", 
                BoxID -> "VertexID$8"], 
               TagBox[
                DiskBox[{4526., 0.}, 0.14955944225389342`], "DynamicName", 
                BoxID -> "VertexID$9"], 
               TagBox[
                DiskBox[{2439., 1442.}, 0.14955944225389342`], "DynamicName", 
                BoxID -> "VertexID$10"], 
               TagBox[
                DiskBox[{3526., 485.}, 0.14955944225389342`], "DynamicName", 
                BoxID -> "VertexID$11"], 
               TagBox[
                DiskBox[{3497., 1500.}, 0.14955944225389342`], "DynamicName", 
                BoxID -> "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$2", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{-0.4142135623730958, 
              61.25954689570648}, {-42.59671354400204, \
-19.585786437626904`}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Cubic\"", ",", 
             RowBox[{"{", 
               RowBox[{"12", ",", "29"}], "}"}]}], "}"}]],
        Annotation[#, {"Cubic", {12, 29}}, "Tooltip"]& ],
       TraditionalForm], {1758.8571428571427`, -1758.8571428571427`}, {
      Center, Center}, {360.0000000000002, 360.0000000000002}], InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 33, 36}, {{2}, {
                  3}, {4}, {1}, {5}, {6}, {1}, {7}, {10}, {1}, {5}, {7}, {
                  2}, {4}, {9}, {2}, {8}, {11}, {3}, {4}, {10}, {6}, {9}, {
                  11}, {5}, {8}, {12}, {3}, {7}, {12}, {6}, {8}, {12}, {9}, {
                  10}, {11}}}, Pattern}]}, {
              VertexCoordinates -> {{0.516, -1.289}, {0.672, -0.605}, {
                0.953, -1.838}, {1.052, -1.197}, {1.233, -0.953}, {
                1.304, -0.3}, {1.304, -1.529}, {1.486, -0.731}, {
                1.519, -0.918}, {1.655, -1.838}, {1.936, -0.605}, {
                2.093, -1.289}}}]], Typeset`boxes = GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{0.516, -1.289}, 0.01908424428880015], "DynamicName", 
                BoxID -> "VertexID$1"], 
               TagBox[
                DiskBox[{0.672, -0.605}, 0.01908424428880015], "DynamicName", 
                BoxID -> "VertexID$2"], 
               TagBox[
                DiskBox[{0.953, -1.838}, 0.01908424428880015], "DynamicName", 
                BoxID -> "VertexID$3"], 
               TagBox[
                DiskBox[{1.052, -1.197}, 0.01908424428880015], "DynamicName", 
                BoxID -> "VertexID$4"], 
               TagBox[
                DiskBox[{1.233, -0.953}, 0.01908424428880015], "DynamicName", 
                BoxID -> "VertexID$5"], 
               TagBox[
                DiskBox[{1.304, -0.3}, 0.01908424428880015], "DynamicName", 
                BoxID -> "VertexID$6"], 
               TagBox[
                DiskBox[{1.304, -1.529}, 0.01908424428880015], "DynamicName", 
                BoxID -> "VertexID$7"], 
               TagBox[
                DiskBox[{1.486, -0.731}, 0.01908424428880015], "DynamicName", 
                BoxID -> "VertexID$8"], 
               TagBox[
                DiskBox[{1.519, -0.918}, 0.01908424428880015], "DynamicName", 
                BoxID -> "VertexID$9"], 
               TagBox[
                DiskBox[{1.655, -1.838}, 0.01908424428880015], "DynamicName", 
                BoxID -> "VertexID$10"], 
               TagBox[
                DiskBox[{1.936, -0.605}, 0.01908424428880015], "DynamicName", 
                BoxID -> "VertexID$11"], 
               TagBox[
                DiskBox[{2.093, -1.289}, 0.01908424428880015], "DynamicName", 
                BoxID -> "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$2", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{-0.055317018814005525`, 
              61.121983685480636`}, {-61.34754689570641, \
-1.5857864376269006`}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Cubic\"", ",", 
             RowBox[{"{", 
               RowBox[{"12", ",", "30"}], "}"}]}], "}"}]],
        Annotation[#, {"Cubic", {12, 30}}, "Tooltip"]& ],
       TraditionalForm], {2149.7142857142853`, -1758.8571428571427`}, {
      Center, Center}, {359.9999999999998, 360.0000000000002}]}, {InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 33, 36}, {{2}, {
                  3}, {4}, {1}, {3}, {5}, {1}, {2}, {6}, {1}, {5}, {7}, {2}, {
                  4}, {8}, {3}, {9}, {10}, {4}, {8}, {11}, {5}, {7}, {12}, {
                  6}, {10}, {11}, {6}, {9}, {12}, {7}, {9}, {12}, {8}, {10}, {
                  11}}}, Pattern}]}, {
              VertexCoordinates -> {{698., 130.}, {742., 325.}, {915., 
                108.}, {437., 218.}, {613., 349.}, {1305., 195.}, {0., 0.}, {
                660., 767.}, {1582., 138.}, {1418., 333.}, {2023., 0.}, {
                1367., 743.}}}]], Typeset`boxes = GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{698., 130.}, 0.1490180193450189], "DynamicName", 
                BoxID -> "VertexID$1"], 
               TagBox[
                DiskBox[{742., 325.}, 0.1490180193450189], "DynamicName", 
                BoxID -> "VertexID$2"], 
               TagBox[
                DiskBox[{915., 108.}, 0.1490180193450189], "DynamicName", 
                BoxID -> "VertexID$3"], 
               TagBox[
                DiskBox[{437., 218.}, 0.1490180193450189], "DynamicName", 
                BoxID -> "VertexID$4"], 
               TagBox[
                DiskBox[{613., 349.}, 0.1490180193450189], "DynamicName", 
                BoxID -> "VertexID$5"], 
               TagBox[
                DiskBox[{1305., 195.}, 0.1490180193450189], "DynamicName", 
                BoxID -> "VertexID$6"], 
               TagBox[
                DiskBox[{0., 0.}, 0.1490180193450189], "DynamicName", BoxID -> 
                "VertexID$7"], 
               TagBox[
                DiskBox[{660., 767.}, 0.1490180193450189], "DynamicName", 
                BoxID -> "VertexID$8"], 
               TagBox[
                DiskBox[{1582., 138.}, 0.1490180193450189], "DynamicName", 
                BoxID -> "VertexID$9"], 
               TagBox[
                DiskBox[{1418., 333.}, 0.1490180193450189], "DynamicName", 
                BoxID -> "VertexID$10"], 
               TagBox[
                DiskBox[{2023., 0.}, 0.1490180193450189], "DynamicName", 
                BoxID -> "VertexID$11"], 
               TagBox[
                DiskBox[{1367., 743.}, 0.1490180193450189], "DynamicName", 
                BoxID -> "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$2", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{-0.4142135623730958, 
              61.259546895706436`}, {-44.41421356237309, \
-18.585786437626904`}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Cubic\"", ",", 
             RowBox[{"{", 
               RowBox[{"12", ",", "32"}], "}"}]}], "}"}]],
        Annotation[#, {"Cubic", {12, 32}}, "Tooltip"]& ],
       TraditionalForm], {195.42857142857142`, -2149.7142857142853`}, {
      Center, Center}, {359.99999999999994`, 359.9999999999998}], InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 33, 36}, {{2}, {
                  3}, {4}, {1}, {3}, {5}, {1}, {2}, {6}, {1}, {5}, {7}, {2}, {
                  4}, {8}, {3}, {9}, {10}, {4}, {9}, {11}, {5}, {10}, {11}, {
                  6}, {7}, {12}, {6}, {8}, {12}, {7}, {8}, {12}, {9}, {10}, {
                  11}}}, Pattern}]}, {
              VertexCoordinates -> {{1772., 447.}, {1942., 177.}, {1587., 
                270.}, {1787., 872.}, {2467., 0.}, {1047., 228.}, {1122., 
                951.}, {0., 0.}, {964., 577.}, {590., 295.}, {615., 897.}, {
                723., 523.}}}]], Typeset`boxes = GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{1772., 447.}, 0.1491937759503366], "DynamicName", 
                BoxID -> "VertexID$1"], 
               TagBox[
                DiskBox[{1942., 177.}, 0.1491937759503366], "DynamicName", 
                BoxID -> "VertexID$2"], 
               TagBox[
                DiskBox[{1587., 270.}, 0.1491937759503366], "DynamicName", 
                BoxID -> "VertexID$3"], 
               TagBox[
                DiskBox[{1787., 872.}, 0.1491937759503366], "DynamicName", 
                BoxID -> "VertexID$4"], 
               TagBox[
                DiskBox[{2467., 0.}, 0.1491937759503366], "DynamicName", 
                BoxID -> "VertexID$5"], 
               TagBox[
                DiskBox[{1047., 228.}, 0.1491937759503366], "DynamicName", 
                BoxID -> "VertexID$6"], 
               TagBox[
                DiskBox[{1122., 951.}, 0.1491937759503366], "DynamicName", 
                BoxID -> "VertexID$7"], 
               TagBox[
                DiskBox[{0., 0.}, 0.1491937759503366], "DynamicName", BoxID -> 
                "VertexID$8"], 
               TagBox[
                DiskBox[{964., 577.}, 0.1491937759503366], "DynamicName", 
                BoxID -> "VertexID$9"], 
               TagBox[
                DiskBox[{590., 295.}, 0.1491937759503366], "DynamicName", 
                BoxID -> "VertexID$10"], 
               TagBox[
                DiskBox[{615., 897.}, 0.1491937759503366], "DynamicName", 
                BoxID -> "VertexID$11"], 
               TagBox[
                DiskBox[{723., 523.}, 0.1491937759503366], "DynamicName", 
                BoxID -> "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$2", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{-0.4142135623730958, 
              61.259546895706436`}, {-44.41421356237309, \
-18.585786437626904`}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Cubic\"", ",", 
             RowBox[{"{", 
               RowBox[{"12", ",", "36"}], "}"}]}], "}"}]],
        Annotation[#, {"Cubic", {12, 36}}, "Tooltip"]& ],
       TraditionalForm], {586.2857142857142, -2149.7142857142853`}, {
      Center, Center}, {359.99999999999994`, 359.9999999999998}], InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 33, 36}, {{2}, {
                  3}, {4}, {1}, {3}, {5}, {1}, {2}, {6}, {1}, {5}, {7}, {2}, {
                  4}, {8}, {3}, {9}, {10}, {4}, {9}, {11}, {5}, {10}, {12}, {
                  6}, {7}, {11}, {6}, {8}, {12}, {7}, {9}, {12}, {8}, {10}, {
                  11}}}, Pattern}]}, {
              VertexCoordinates -> {{823., 194.}, {888., 75.}, {737., 118.}, {
                844., 356.}, {1104., 0.}, {500., 128.}, {605., 399.}, {0., 
                0.}, {519., 289.}, {244., 122.}, {452., 366.}, {232., 
                360.}}}]], Typeset`boxes = GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{823., 194.}, 0.14821061107631744`], "DynamicName", 
                BoxID -> "VertexID$1"], 
               TagBox[
                DiskBox[{888., 75.}, 0.14821061107631744`], "DynamicName", 
                BoxID -> "VertexID$2"], 
               TagBox[
                DiskBox[{737., 118.}, 0.14821061107631744`], "DynamicName", 
                BoxID -> "VertexID$3"], 
               TagBox[
                DiskBox[{844., 356.}, 0.14821061107631744`], "DynamicName", 
                BoxID -> "VertexID$4"], 
               TagBox[
                DiskBox[{1104., 0.}, 0.14821061107631744`], "DynamicName", 
                BoxID -> "VertexID$5"], 
               TagBox[
                DiskBox[{500., 128.}, 0.14821061107631744`], "DynamicName", 
                BoxID -> "VertexID$6"], 
               TagBox[
                DiskBox[{605., 399.}, 0.14821061107631744`], "DynamicName", 
                BoxID -> "VertexID$7"], 
               TagBox[
                DiskBox[{0., 0.}, 0.14821061107631744`], "DynamicName", BoxID -> 
                "VertexID$8"], 
               TagBox[
                DiskBox[{519., 289.}, 0.14821061107631744`], "DynamicName", 
                BoxID -> "VertexID$9"], 
               TagBox[
                DiskBox[{244., 122.}, 0.14821061107631744`], "DynamicName", 
                BoxID -> "VertexID$10"], 
               TagBox[
                DiskBox[{452., 366.}, 0.14821061107631744`], "DynamicName", 
                BoxID -> "VertexID$11"], 
               TagBox[
                DiskBox[{232., 360.}, 0.14821061107631744`], "DynamicName", 
                BoxID -> "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$2", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{-0.4142135623730958, 
              
              61.25954689570645}, {-43.47964381636578, \
-18.585786437626904`}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Cubic\"", ",", 
             RowBox[{"{", 
               RowBox[{"12", ",", "37"}], "}"}]}], "}"}]],
        Annotation[#, {"Cubic", {12, 37}}, "Tooltip"]& ],
       TraditionalForm], {977.1428571428571, -2149.7142857142853`}, {
      Center, Center}, {360., 359.9999999999998}], InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 33, 36}, {{2}, {
                  3}, {4}, {1}, {3}, {5}, {1}, {2}, {6}, {1}, {7}, {8}, {2}, {
                  7}, {9}, {3}, {8}, {10}, {4}, {5}, {11}, {4}, {6}, {11}, {
                  5}, {10}, {12}, {6}, {9}, {12}, {7}, {8}, {12}, {9}, {10}, {
                  11}}}, Pattern}]}, {
              VertexCoordinates -> {{1468., 839.}, {1049., 524.}, {1679., 
                315.}, {1676., 1207.}, {0., 0.}, {2520., 420.}, {1360., 
                1729.}, {2200., 1103.}, {4871., 0.}, {3681., 580.}, {2404., 
                1887.}, {3652., 1785.}}}]], Typeset`boxes = GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{1468., 839.}, 0.14959055827379367`], "DynamicName", 
                BoxID -> "VertexID$1"], 
               TagBox[
                DiskBox[{1049., 524.}, 0.14959055827379367`], "DynamicName", 
                BoxID -> "VertexID$2"], 
               TagBox[
                DiskBox[{1679., 315.}, 0.14959055827379367`], "DynamicName", 
                BoxID -> "VertexID$3"], 
               TagBox[
                DiskBox[{1676., 1207.}, 0.14959055827379367`], "DynamicName", 
                BoxID -> "VertexID$4"], 
               TagBox[
                DiskBox[{0., 0.}, 0.14959055827379367`], "DynamicName", BoxID -> 
                "VertexID$5"], 
               TagBox[
                DiskBox[{2520., 420.}, 0.14959055827379367`], "DynamicName", 
                BoxID -> "VertexID$6"], 
               TagBox[
                DiskBox[{1360., 1729.}, 0.14959055827379367`], "DynamicName", 
                BoxID -> "VertexID$7"], 
               TagBox[
                DiskBox[{2200., 1103.}, 0.14959055827379367`], "DynamicName", 
                BoxID -> "VertexID$8"], 
               TagBox[
                DiskBox[{4871., 0.}, 0.14959055827379367`], "DynamicName", 
                BoxID -> "VertexID$9"], 
               TagBox[
                DiskBox[{3681., 580.}, 0.14959055827379367`], "DynamicName", 
                BoxID -> "VertexID$10"], 
               TagBox[
                DiskBox[{2404., 1887.}, 0.14959055827379367`], "DynamicName", 
                BoxID -> "VertexID$11"], 
               TagBox[
                DiskBox[{3652., 1785.}, 0.14959055827379367`], "DynamicName", 
                BoxID -> "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$2", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{-0.4142135623730958, 
              61.25954689570648}, {-44.41421356237309, \
-18.585786437626904`}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Cubic\"", ",", 
             RowBox[{"{", 
               RowBox[{"12", ",", "46"}], "}"}]}], "}"}]],
        Annotation[#, {"Cubic", {12, 46}}, "Tooltip"]& ],
       TraditionalForm], {1368., -2149.7142857142853`}, {
      Center, Center}, {360.0000000000002, 359.9999999999998}], InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 33, 36}, {{2}, {
                  3}, {4}, {1}, {3}, {5}, {1}, {2}, {6}, {1}, {7}, {8}, {2}, {
                  7}, {9}, {3}, {8}, {10}, {4}, {5}, {11}, {4}, {6}, {12}, {
                  5}, {10}, {11}, {6}, {9}, {12}, {7}, {9}, {12}, {8}, {10}, {
                  11}}}, Pattern}]}, {
              VertexCoordinates -> {{3578., 431.}, {2716., 615.}, {3084., 
                1046.}, {4934., 0.}, {1486., 743.}, {2958., 1527.}, {0., 
                0.}, {3427., 2344.}, {1742., 1668.}, {2363., 1540.}, {1377., 
                2174.}, {2389., 2357.}}}]], Typeset`boxes = GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{3578., 431.}, 0.14959577177274289`], "DynamicName", 
                BoxID -> "VertexID$1"], 
               TagBox[
                DiskBox[{2716., 615.}, 0.14959577177274289`], "DynamicName", 
                BoxID -> "VertexID$2"], 
               TagBox[
                DiskBox[{3084., 1046.}, 0.14959577177274289`], "DynamicName", 
                BoxID -> "VertexID$3"], 
               TagBox[
                DiskBox[{4934., 0.}, 0.14959577177274289`], "DynamicName", 
                BoxID -> "VertexID$4"], 
               TagBox[
                DiskBox[{1486., 743.}, 0.14959577177274289`], "DynamicName", 
                BoxID -> "VertexID$5"], 
               TagBox[
                DiskBox[{2958., 1527.}, 0.14959577177274289`], "DynamicName", 
                BoxID -> "VertexID$6"], 
               TagBox[
                DiskBox[{0., 0.}, 0.14959577177274289`], "DynamicName", BoxID -> 
                "VertexID$7"], 
               TagBox[
                DiskBox[{3427., 2344.}, 0.14959577177274289`], "DynamicName", 
                BoxID -> "VertexID$8"], 
               TagBox[
                DiskBox[{1742., 1668.}, 0.14959577177274289`], "DynamicName", 
                BoxID -> "VertexID$9"], 
               TagBox[
                DiskBox[{2363., 1540.}, 0.14959577177274289`], "DynamicName", 
                BoxID -> "VertexID$10"], 
               TagBox[
                DiskBox[{1377., 2174.}, 0.14959577177274289`], "DynamicName", 
                BoxID -> "VertexID$11"], 
               TagBox[
                DiskBox[{2389., 2357.}, 0.14959577177274289`], "DynamicName", 
                BoxID -> "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$2", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$11", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{-0.4142135623730958, 
              61.25954689570649}, {-46.88431845202874, \
-15.585786437626904`}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Cubic\"", ",", 
             RowBox[{"{", 
               RowBox[{"12", ",", "47"}], "}"}]}], "}"}]],
        Annotation[#, {"Cubic", {12, 47}}, "Tooltip"]& ],
       TraditionalForm], {1758.8571428571427`, -2149.7142857142853`}, {
      Center, Center}, {360.0000000000002, 359.9999999999998}], InsetBox[
      FormBox[
       TagBox[
        TooltipBox[
         GraphicsBox[
          NamespaceBox["NetworkGraphics",
           DynamicModuleBox[{Typeset`graph = HoldComplete[
             Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12}, {Null, 
               SparseArray[
               Automatic, {12, 12}, 0, {
                1, {{0, 3, 6, 9, 12, 15, 18, 21, 24, 27, 30, 33, 36}, {{2}, {
                  3}, {4}, {1}, {3}, {5}, {1}, {2}, {6}, {1}, {7}, {8}, {2}, {
                  7}, {9}, {3}, {10}, {11}, {4}, {5}, {12}, {4}, {10}, {12}, {
                  5}, {11}, {12}, {6}, {8}, {11}, {6}, {9}, {10}, {7}, {8}, {
                  9}}}, Pattern}]}, {
              VertexCoordinates -> {{2356., 2300.}, {3104., 2435.}, {2625., 
                1926.}, {1339., 2139.}, {4331., 0.}, {2415., 1671.}, {0., 
                0.}, {1661., 1631.}, {2749., 639.}, {2174., 1535.}, {2446., 
                1415.}, {1470., 735.}}}]], Typeset`boxes = 
            GraphicsGroupBox[{{
               Directive[
                Hue[0.6, 0.2, 0.8], 
                EdgeForm[
                 Directive[
                  GrayLevel[0], 
                  Opacity[0.7]]]], 
               TagBox[
                DiskBox[{2356., 2300.}, 0.14953966902202684`], "DynamicName", 
                BoxID -> "VertexID$1"], 
               TagBox[
                DiskBox[{3104., 2435.}, 0.14953966902202684`], "DynamicName", 
                BoxID -> "VertexID$2"], 
               TagBox[
                DiskBox[{2625., 1926.}, 0.14953966902202684`], "DynamicName", 
                BoxID -> "VertexID$3"], 
               TagBox[
                DiskBox[{1339., 2139.}, 0.14953966902202684`], "DynamicName", 
                BoxID -> "VertexID$4"], 
               TagBox[
                DiskBox[{4331., 0.}, 0.14953966902202684`], "DynamicName", 
                BoxID -> "VertexID$5"], 
               TagBox[
                DiskBox[{2415., 1671.}, 0.14953966902202684`], "DynamicName", 
                BoxID -> "VertexID$6"], 
               TagBox[
                DiskBox[{0., 0.}, 0.14953966902202684`], "DynamicName", BoxID -> 
                "VertexID$7"], 
               TagBox[
                DiskBox[{1661., 1631.}, 0.14953966902202684`], "DynamicName", 
                BoxID -> "VertexID$8"], 
               TagBox[
                DiskBox[{2749., 639.}, 0.14953966902202684`], "DynamicName", 
                BoxID -> "VertexID$9"], 
               TagBox[
                DiskBox[{2174., 1535.}, 0.14953966902202684`], "DynamicName", 
                BoxID -> "VertexID$10"], 
               TagBox[
                DiskBox[{2446., 1415.}, 0.14953966902202684`], "DynamicName", 
                BoxID -> "VertexID$11"], 
               TagBox[
                DiskBox[{1470., 735.}, 0.14953966902202684`], "DynamicName", 
                BoxID -> "VertexID$12"]}, {
               Directive[
                Opacity[0.7], 
                Hue[0.6, 0.7, 0.5]], 
               LineBox[{{
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$2", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$1", Automatic, Center], 
                  DynamicLocation["VertexID$4", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$3", Automatic, Center]}, {
                  DynamicLocation["VertexID$2", Automatic, Center], 
                  DynamicLocation["VertexID$5", Automatic, Center]}, {
                  DynamicLocation["VertexID$3", Automatic, Center], 
                  DynamicLocation["VertexID$6", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$4", Automatic, Center], 
                  DynamicLocation["VertexID$8", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$7", Automatic, Center]}, {
                  DynamicLocation["VertexID$5", Automatic, Center], 
                  DynamicLocation["VertexID$9", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$6", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$7", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$10", Automatic, Center]}, {
                  DynamicLocation["VertexID$8", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}, {
                  DynamicLocation["VertexID$9", Automatic, Center], 
                  DynamicLocation["VertexID$12", Automatic, Center]}, {
                  DynamicLocation["VertexID$10", Automatic, Center], 
                  DynamicLocation["VertexID$11", Automatic, Center]}}]}}]}, 
            
            DynamicBox[GraphComputation`NetworkGraphicsBox[
             1, Typeset`graph, Typeset`boxes], {
             CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
              SynchronousUpdating -> False, TrackedSymbols :> {}},
             
             ImageSizeCache->{{-0.4142135623730958, 
              61.25954689570642}, {-49.36172934751403, \
-12.585786437626904`}}]]],
          
          DefaultBaseStyle->{
           "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
            Hue[0.8, 1., 0.6]},
          FrameTicks->None],
         RowBox[{"{", 
           RowBox[{"\"Cubic\"", ",", 
             RowBox[{"{", 
               RowBox[{"12", ",", "58"}], "}"}]}], "}"}]],
        Annotation[#, {"Cubic", {12, 58}}, "Tooltip"]& ],
       TraditionalForm], {2149.7142857142853`, -2149.7142857142853`}, {
      Center, Center}, {359.9999999999998, 359.9999999999998}]}}, {}},
  ContentSelectable->True,
  ImageSize->400,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{{3.5055249578153667`*^9, 3.505525004457447*^9}, 
   3.5055251246545362`*^9, 3.505525623310145*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{740, 752},
WindowMargins->{{118, Automatic}, {19, Automatic}},
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (November 6, \
2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 145, 2, 67, "Section"],
Cell[727, 26, 13138, 351, 1288, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[13902, 382, 102, 1, 37, "Section"],
Cell[CellGroupData[{
Cell[14029, 387, 514, 13, 73, "Input"],
Cell[14546, 402, 43162, 999, 365, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57745, 1406, 132, 2, 27, "Input"],
Cell[57880, 1410, 4597, 123, 193, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[62526, 1539, 145, 2, 67, "Section"],
Cell[CellGroupData[{
Cell[62696, 1545, 350, 6, 27, "Input"],
Cell[63049, 1553, 270, 6, 20, "Print"],
Cell[63322, 1561, 232882, 4404, 415, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
